@@ -44,6 +44,7 @@ extensions = [
     "sphinx.ext.todo",
     "sphinx.ext.graphviz",
 ]
+autodoc_type_aliases = {"DevState": "DevState"}
 
 # Add any paths that contain templates here, relative to this directory.
 templates_path = ["_templates"]
@@ -141,7 +142,6 @@ html_context = {
         # 'https://media.readthedocs.org/css/sphinx_rtd_theme.css',
         # 'https://media.readthedocs.org/css/readthedocs-doc-embed.css',
         # '_static/jssor.css',
-        "_static/css/tango_cs_theme.css",
     ],
 }
 
@@ -262,6 +262,7 @@ rst_epilog = """\
 .. _Conda-forge: https://anaconda.org/conda-forge/pytango
 .. _Miniforge3: https://github.com/conda-forge/miniforge#miniforge3
 .. _Miniconda: https://docs.conda.io/en/latest/miniconda.html
+.. _OpenTelemetry: https://opentelemetry.io/docs/what-is-opentelemetry/
 
 """
 
@@ -275,6 +276,7 @@ intersphinx_mapping = {
     "couchdb": ("https://couchdb-python.readthedocs.io/en/latest", None),
     "pycassa": ("https://pycassa.github.io/pycassa", None),
     "sqlalchemy": ("https://docs.sqlalchemy.org/en/latest", None),
+    "opentelemetry": ("https://opentelemetry-python.readthedocs.io/en/latest", None),
 }
 
 todo_include_todos = True
@@ -351,7 +353,7 @@ def parse_bullet_with_type(line):
 
 
 def parse_throws(line):
-    words = re.split("(\W+)", line)
+    words = re.split(r"(\W+)", line)
     assert line == "".join(words)
     return "".join(map(type_to_pytango_link, words))
 
