@@ -31,8 +31,10 @@ __all__ = ("tango",)
 
 
 # Constants
-TANGO_VERSION = "9.5.0"
-TANGO_VERSION_INT = int(TANGO_VERSION[::2])
+TANGO_VERSION = "10.0.0"
+TANGO_VERSION_INT = int(TANGO_VERSION.replace(".", ""))
+
+LATEST_DEVICE_IMPLEMENTATION = 6
 
 
 # Extension mock class
@@ -52,7 +54,7 @@ class ExtensionMock(MagicMock):
 
     def __getattr__(self, name):
         # Limit device class discovery
-        if name == "Device_6Impl":
+        if name == f"Device_{LATEST_DEVICE_IMPLEMENTATION+1}Impl":
             raise AttributeError
         # Regular mock behavior
         return MagicMock.__getattr__(self, name)
@@ -102,9 +104,12 @@ def set_device_implementations(module):
     attrs = {"__module__": module.__name__}
     module.DeviceImpl = type("DeviceImpl", (object,), attrs)
     module.Device_2Impl = type("Device_2Impl", (module.DeviceImpl,), attrs)
-    module.Device_3Impl = type("Device_3Impl", (module.Device_2Impl,), attrs)
-    module.Device_4Impl = type("Device_4Impl", (module.Device_3Impl,), attrs)
-    module.Device_5Impl = type("Device_5Impl", (module.Device_4Impl,), attrs)
+    for ind in range(3, LATEST_DEVICE_IMPLEMENTATION + 1):
+        setattr(
+            module,
+            f"Device_{ind}Impl",
+            type(f"Device_{ind}Impl", (getattr(module, f"Device_{ind-1}Impl"),), attrs),
+        )
 
 
 # Use empty classes for device proxy inheritance scheme
@@ -145,4 +150,7 @@ print("Mocking tango._tango extension module")
 
 
 # Try to import
-import tango
+try:
+    import tango
+except Exception as err:
+    print(err)
