@@ -12,15 +12,12 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_archive_event_info()
 {
-    class_<Tango::ArchiveEventInfo>("ArchiveEventInfo")
+    bopy::class_<Tango::ArchiveEventInfo>("ArchiveEventInfo")
         .enable_pickling()
         .def_readwrite("archive_rel_change", &Tango::ArchiveEventInfo::archive_rel_change)
         .def_readwrite("archive_abs_change", &Tango::ArchiveEventInfo::archive_abs_change)
         .def_readwrite("archive_period", &Tango::ArchiveEventInfo::archive_period)
-        .def_readwrite("extensions", &Tango::ArchiveEventInfo::extensions)
-    ;
+        .def_readwrite("extensions", &Tango::ArchiveEventInfo::extensions);
 }
