@@ -12,11 +12,9 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_attribute_alarm_info()
 {
-    class_<Tango::AttributeAlarmInfo>("AttributeAlarmInfo")
+    bopy::class_<Tango::AttributeAlarmInfo>("AttributeAlarmInfo")
         .enable_pickling()
         .def_readwrite("min_alarm", &Tango::AttributeAlarmInfo::min_alarm)
         .def_readwrite("max_alarm", &Tango::AttributeAlarmInfo::max_alarm)
@@ -24,6 +22,5 @@ void export_attribute_alarm_info()
         .def_readwrite("max_warning", &Tango::AttributeAlarmInfo::max_warning)
         .def_readwrite("delta_t", &Tango::AttributeAlarmInfo::delta_t)
         .def_readwrite("delta_val", &Tango::AttributeAlarmInfo::delta_val)
-        .def_readwrite("extensions", &Tango::AttributeAlarmInfo::extensions)
-    ;
+        .def_readwrite("extensions", &Tango::AttributeAlarmInfo::extensions);
 }
