@@ -12,14 +12,10 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_attribute_info()
 {
-    class_<Tango::AttributeInfo, bases<Tango::DeviceAttributeConfig> >
-        ("AttributeInfo")
-        .def(init<const Tango::AttributeInfo&>())
+    bopy::class_<Tango::AttributeInfo, bopy::bases<Tango::DeviceAttributeConfig>>("AttributeInfo")
+        .def(bopy::init<const Tango::AttributeInfo &>())
         .enable_pickling()
-        .def_readwrite("disp_level", &Tango::AttributeInfo::disp_level)
-    ;
+        .def_readwrite("disp_level", &Tango::AttributeInfo::disp_level);
 }
