@@ -12,14 +12,11 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_change_event_info()
 {
-    class_<Tango::ChangeEventInfo>("ChangeEventInfo")
+    bopy::class_<Tango::ChangeEventInfo>("ChangeEventInfo")
         .enable_pickling()
         .def_readwrite("rel_change", &Tango::ChangeEventInfo::rel_change)
         .def_readwrite("abs_change", &Tango::ChangeEventInfo::abs_change)
-        .def_readwrite("extensions", &Tango::ChangeEventInfo::extensions)
-    ;
+        .def_readwrite("extensions", &Tango::ChangeEventInfo::extensions);
 }
