@@ -12,11 +12,8 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_command_info()
 {
-    class_<Tango::CommandInfo , bases<Tango::DevCommandInfo> >("CommandInfo")
-        .def_readonly("disp_level", &Tango::CommandInfo::disp_level)
-        ;
+    bopy::class_<Tango::CommandInfo, bopy::bases<Tango::DevCommandInfo>>("CommandInfo")
+        .def_readonly("disp_level", &Tango::CommandInfo::disp_level);
 }
