@@ -18,17 +18,17 @@
 #define xstr(a) str(a)
 #define str(a) #a
 
-using namespace boost::python;
-
 long TANGO_VERSION_HEX;
 
 // Some internal constants were removed from cppTango in 9.4. To support both
 // 9.4 and previous versions we must export constants conditionally, skipping
-// the ones that are no longer available in cppTango. For each constant that 
+// the ones that are no longer available in cppTango. For each constant that
 // could missing we must define a dummy fallback value of the type specified
 // below, in the global namespace. This type is later used to detect missing
 // constants using a template specialization.
-struct PyTangoFallbackConstant {};
+struct PyTangoFallbackConstant
+{
+};
 
 static const PyTangoFallbackConstant MIN_POLL_PERIOD;
 static const PyTangoFallbackConstant DELTA_T;
@@ -44,20 +44,20 @@ static const PyTangoFallbackConstant DELTA_PERIODIC_LONG;
 static const PyTangoFallbackConstant RECONNECTION_DELAY;
 
 template <typename T>
-static void export_conditionally(scope& consts_scope, const char* name, T value)
+static void export_conditionally(bopy::scope &consts_scope, const char *name, T value)
 {
     consts_scope.attr(name) = value;
 }
 
 template <>
-void export_conditionally(scope& /*consts_scope*/, const char* /*name*/, PyTangoFallbackConstant)
+void export_conditionally(bopy::scope & /*consts_scope*/, const char * /*name*/, PyTangoFallbackConstant)
 {
     // Do nothing for missing constants.
 }
 
 namespace Tango
 {
-static void export_optional_constants(scope& consts_scope)
+static void export_optional_constants(bopy::scope &consts_scope)
 {
     // This function must be defined in the Tango namespace and all constants
     // must be referenced using unqualified names. They are resolved either to
@@ -87,16 +87,16 @@ static void export_optional_constants(scope& consts_scope)
     //
     export_conditionally(consts_scope, "RECONNECTION_DELAY", RECONNECTION_DELAY);
 }
-}
+} // namespace Tango
 
 void export_constants()
 {
-    object consts_module(handle<>(borrowed(PyImport_AddModule("tango.constants"))));
-    scope().attr("constants") = consts_module;
-    scope consts_scope = consts_module;
+    bopy::object consts_module(bopy::handle<>(bopy::borrowed(PyImport_AddModule("tango.constants"))));
+    bopy::scope().attr("constants") = consts_module;
+    bopy::scope consts_scope = consts_module;
 
     consts_scope.attr("__doc__") = "module containing several Tango constants.\n"
-        "\nNew in PyTango 7.0.0";
+                                   "\nNew in PyTango 7.0.0";
 
     consts_scope.attr("NUMPY_VERSION") = xstr(PYTANGO_NUMPY_VERSION);
 
@@ -111,7 +111,6 @@ void export_constants()
     consts_scope.attr("BOOST_PATCH_VERSION") = BOOST_VERSION % 100;
     // missing BOOST_VERSION => do it in python
 
-
     //
     // From tango_const.h
     //
@@ -135,7 +134,7 @@ void export_constants()
     consts_scope.attr("DefaultBlackBoxDepth") = Tango::DefaultBlackBoxDepth;
     consts_scope.attr("DefaultPollRingDepth") = Tango::DefaultPollRingDepth;
 
-    consts_scope.attr("InitialOutput") =Tango:: InitialOutput;
+    consts_scope.attr("InitialOutput") = Tango::InitialOutput;
     consts_scope.attr("DSDeviceDomain") = Tango::DSDeviceDomain;
     consts_scope.attr("DefaultDocUrl") = Tango::DefaultDocUrl;
     consts_scope.attr("EnvVariable") = Tango::EnvVariable;
@@ -263,6 +262,16 @@ void export_constants()
 
     consts_scope.attr("MAX_GIOP_PER_SERVER") = Tango::MAX_GIOP_PER_SERVER;
 
+    //
+    // Telemetry related defines
+    //
+
+#if defined(TANGO_USE_TELEMETRY)
+    consts_scope.attr("TELEMETRY_SUPPORTED") = true;
+#else
+    consts_scope.attr("TELEMETRY_SUPPORTED") = false;
+#endif
+
     //
     // Tango name length
     //
@@ -378,5 +387,4 @@ void export_constants()
     consts_scope.attr("API_WrongHistoryDataBuffer") = Tango::API_WrongHistoryDataBuffer;
     consts_scope.attr("API_WrongLockingStatus") = Tango::API_WrongLockingStatus;
     consts_scope.attr("API_ZmqInitFailed") = Tango::API_ZmqInitFailed;
-
 }
