@@ -22,26 +22,29 @@ typedef std::vector<double> StdDoubleVector;
 
 namespace PyTango
 {
-    enum ExtractAs {
-        ExtractAsNumpy,
-        ExtractAsByteArray,
-        ExtractAsBytes,
-        ExtractAsTuple,
-        ExtractAsList,
-        ExtractAsString,
-        ExtractAsPyTango3,
-        ExtractAsNothing
-    };
-    
-    enum ImageFormat {
-        RawImage,
-        JpegImage
-    };
+enum ExtractAs
+{
+    ExtractAsNumpy,
+    ExtractAsByteArray,
+    ExtractAsBytes,
+    ExtractAsTuple,
+    ExtractAsList,
+    ExtractAsString,
+    ExtractAsPyTango3,
+    ExtractAsNothing
+};
 
-    enum GreenMode {
-        GreenModeSynchronous,
-        GreenModeFutures,
-        GreenModeGevent,
-        GreenModeAsyncio
-    };
-}
+enum ImageFormat
+{
+    RawImage,
+    JpegImage
+};
+
+enum GreenMode
+{
+    GreenModeSynchronous,
+    GreenModeFutures,
+    GreenModeGevent,
+    GreenModeAsyncio
+};
+} // namespace PyTango
