@@ -13,17 +13,11 @@
 #include <tango/tango.h>
 #include "pyutils.h"
 
-using namespace boost::python;
-
 void export_device_attribute_history()
 {
+    bopy::class_<Tango::DeviceAttributeHistory, bopy::bases<Tango::DeviceAttribute>> DeviceAttributeHistory(
+        "DeviceAttributeHistory", bopy::init<>());
 
-    class_<Tango::DeviceAttributeHistory, bases<Tango::DeviceAttribute> >
-            DeviceAttributeHistory("DeviceAttributeHistory", init<>());
-
-    DeviceAttributeHistory
-        .def(init<const Tango::DeviceAttributeHistory &>())
-
-        .def("has_failed", &Tango::DeviceAttributeHistory::has_failed)
-    ;
+    DeviceAttributeHistory.def(bopy::init<const Tango::DeviceAttributeHistory &>())
+        .def("has_failed", &Tango::DeviceAttributeHistory::has_failed);
 }
