@@ -12,20 +12,17 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_device_data_history()
 {
-    class_<Tango::DeviceDataHistory, bases<Tango::DeviceData> >
-            DeviceDataHistory("DeviceDataHistory", init<>());
+    bopy::class_<Tango::DeviceDataHistory, bopy::bases<Tango::DeviceData>> DeviceDataHistory("DeviceDataHistory",
+                                                                                             bopy::init<>());
 
     DeviceDataHistory
-        .def(init<const Tango::DeviceDataHistory &>())
+        .def(bopy::init<const Tango::DeviceDataHistory &>())
 
         .def("has_failed", &Tango::DeviceDataHistory::has_failed)
-        .def("get_date", &Tango::DeviceDataHistory::get_date,
-            return_internal_reference<>())
-        .def("get_err_stack", &Tango::DeviceDataHistory::get_err_stack,
-            return_value_policy<copy_const_reference>())
-    ;
+        .def("get_date", &Tango::DeviceDataHistory::get_date, bopy::return_internal_reference<>())
+        .def("get_err_stack",
+             &Tango::DeviceDataHistory::get_err_stack,
+             bopy::return_value_policy<bopy::copy_const_reference>());
 }
