@@ -14,20 +14,17 @@
 
 struct PyLockerInfo
 {
-    static inline boost::python::object get_locker_id(Tango::LockerInfo &li)
+    static inline bopy::object get_locker_id(Tango::LockerInfo &li)
     {
-        return (li.ll == Tango::CPP) ?
-            boost::python::object(li.li.LockerPid) :
-            boost::python::tuple(li.li.UUID);
+        return (li.ll == Tango::CPP) ? bopy::object(li.li.LockerPid) : bopy::tuple(li.li.UUID);
     }
 };
 
 void export_locker_info()
 {
-    boost::python::class_<Tango::LockerInfo>("LockerInfo")
+    bopy::class_<Tango::LockerInfo>("LockerInfo")
         .def_readonly("ll", &Tango::LockerInfo::ll)
         .add_property("li", &PyLockerInfo::get_locker_id)
         .def_readonly("locker_host", &Tango::LockerInfo::locker_host)
-        .def_readonly("locker_class", &Tango::LockerInfo::locker_class)
-    ;
+        .def_readonly("locker_class", &Tango::LockerInfo::locker_class);
 }
