@@ -12,10 +12,7 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_locking_thread()
 {
-    class_<Tango::LockingThread>("LockingThread")
-    ;
+    bopy::class_<Tango::LockingThread>("LockingThread");
 }
