@@ -12,13 +12,10 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_periodic_event_info()
 {
-    class_<Tango::PeriodicEventInfo>("PeriodicEventInfo")
+    bopy::class_<Tango::PeriodicEventInfo>("PeriodicEventInfo")
         .enable_pickling()
         .def_readwrite("period", &Tango::PeriodicEventInfo::period)
-        .def_readwrite("extensions", &Tango::PeriodicEventInfo::extensions)
-    ;
+        .def_readwrite("extensions", &Tango::PeriodicEventInfo::extensions);
 }
