@@ -12,19 +12,15 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_pipe_info()
 {
-    class_<Tango::PipeInfo>
-        ("PipeInfo")
-        .def(init<const Tango::PipeInfo&>())
+    bopy::class_<Tango::PipeInfo>("PipeInfo")
+        .def(bopy::init<const Tango::PipeInfo &>())
         .enable_pickling()
-	.def_readwrite("name",  &Tango::PipeInfo::name)
-	.def_readwrite("description",  &Tango::PipeInfo::description)
-	.def_readwrite("label",  &Tango::PipeInfo::label)
+        .def_readwrite("name", &Tango::PipeInfo::name)
+        .def_readwrite("description", &Tango::PipeInfo::description)
+        .def_readwrite("label", &Tango::PipeInfo::label)
         .def_readwrite("disp_level", &Tango::PipeInfo::disp_level)
         .def_readwrite("writable", &Tango::PipeInfo::writable)
-        .def_readwrite("extensions", &Tango::PipeInfo::extensions)
-    ;
+        .def_readwrite("extensions", &Tango::PipeInfo::extensions);
 }
