@@ -15,6 +15,7 @@
 // use this precompiled header.
 
 #define BOOST_BIND_GLOBAL_PLACEHOLDERS
+#define BOOST_ALLOW_DEPRECATED_HEADERS
 
 #include <boost/python.hpp>
 #include <boost/version.hpp>
@@ -30,5 +31,6 @@
 #include <sstream>
 #include <memory>
 
-//#include <tango/tango.h>
+namespace bopy = boost::python;
 
+// #include <tango/tango.h>
