@@ -11,17 +11,11 @@
 
 #include "precompiled_header.hpp"
 
-#if BOOST_VERSION < 103400
-#define DISABLE_BOOST_DOCSTRING_OPTIONS
-#endif
-
 #define PY_ARRAY_UNIQUE_SYMBOL pytango_ARRAY_API
 #include <numpy/arrayobject.h>
 
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_version();
 void export_enums();
 void export_constants();
@@ -58,21 +52,20 @@ void export_group();
 void export_log4tango();
 void export_auto_tango_monitor();
 void export_ensure_omni_thread();
+void export_telemetry_helpers();
 
-void* init_numpy(void) { import_array(); return NULL; }
-
+void *init_numpy(void)
+{
+    import_array();
+    return NULL;
+}
 
 BOOST_PYTHON_MODULE(_tango)
 {
-
-#ifndef DISABLE_BOOST_DOCSTRING_OPTIONS
-    // Configure generated docstrings
     const bool show_user_defined = false;
     const bool show_py_signatures = false;
 
-    docstring_options doc_opts(show_user_defined,
-                               show_py_signatures);
-#endif
+    bopy::docstring_options doc_opts(show_user_defined, show_py_signatures);
 
     init_numpy();
 
@@ -114,4 +107,5 @@ BOOST_PYTHON_MODULE(_tango)
     export_log4tango();
     export_auto_tango_monitor();
     export_ensure_omni_thread();
- }
+    export_telemetry_helpers();
+}
