@@ -24,7 +24,7 @@
 class AutoPythonGIL
 {
     PyGILState_STATE m_gstate;
-    
+
     /**
      * Check python. Before acquiring python GIL check if python as not been
      * shutdown. If this is the case then the best we can do here is throw an
@@ -34,22 +34,26 @@ class AutoPythonGIL
     {
         if(!Py_IsInitialized())
         {
-            Tango::Except::throw_exception(
-                "AutoPythonGIL_PythonShutdown",
-                "Trying to execute python code when python interpreter as shutdown.",
-                "AutoPythonGIL::check_python");
+            Tango::Except::throw_exception("AutoPythonGIL_PythonShutdown",
+                                           "Trying to execute python code when python interpreter as shutdown.",
+                                           "AutoPythonGIL::check_python");
         }
     }
 
-public:
-    inline AutoPythonGIL(bool safe=true) 
-    { 
-        if (safe) check_python();
-        m_gstate = PyGILState_Ensure(); 
+  public:
+    inline AutoPythonGIL(bool safe = true)
+    {
+        if(safe)
+        {
+            check_python();
+        }
+        m_gstate = PyGILState_Ensure();
+    }
+
+    inline ~AutoPythonGIL()
+    {
+        PyGILState_Release(m_gstate);
     }
-    
-    inline ~AutoPythonGIL() { PyGILState_Release(m_gstate); }
-    
 };
 
 /**
@@ -62,10 +66,10 @@ inline void double2timeval(struct timeval &tv, double t)
 {
     double sec = floor(t);
 #ifdef WIN32
-    tv.tv_usec = (long)((t-sec)*1.0E6);
-    tv.tv_sec = (long)(sec);
+    tv.tv_usec = (long) ((t - sec) * 1.0E6);
+    tv.tv_sec = (long) (sec);
 #else
-    tv.tv_usec = (time_t)((t-sec)*1.0E6);
-    tv.tv_sec = (suseconds_t)(sec);
+    tv.tv_usec = (time_t) ((t - sec) * 1.0E6);
+    tv.tv_sec = (suseconds_t) (sec);
 #endif
 }
