@@ -15,27 +15,28 @@
 #include <tango/tango.h>
 #include <omnithread.h>
 
-namespace bopy = boost::python;
-
-#define arg_(a) boost::python::arg(a)
+#define arg_(a) bopy::arg(a)
 
 inline void raise_(PyObject *type, const char *message)
 {
     PyErr_SetString(type, message);
-    boost::python::throw_error_already_set();
+    bopy::throw_error_already_set();
 }
 
-inline PyObject* EncodeAsLatin1(PyObject *in)
+inline PyObject *EncodeAsLatin1(PyObject *in)
 {
-    PyObject* bytes_out = PyUnicode_AsLatin1String(in);
-    if (!bytes_out)
+    PyObject *bytes_out = PyUnicode_AsLatin1String(in);
+    if(!bytes_out)
     {
-        PyObject* bytes_replaced = PyUnicode_AsEncodedString(in, "latin-1", "replace");
-        const char* string_replaced = PyBytes_AsString(bytes_replaced);
+        PyObject *bytes_replaced = PyUnicode_AsEncodedString(in, "latin-1", "replace");
+        const char *string_replaced = PyBytes_AsString(bytes_replaced);
         std::string err_msg = "Can't encode ";
-        if (!string_replaced) {
+        if(!string_replaced)
+        {
             err_msg += "unknown Unicode string as Latin-1";
-        } else {
+        }
+        else
+        {
             err_msg += "'";
             err_msg += string_replaced;
             err_msg += "' Unicode string as Latin-1 (bad chars replaced with ?)";
@@ -47,7 +48,6 @@ inline PyObject* EncodeAsLatin1(PyObject *in)
     return bytes_out;
 }
 
-
 inline PyObject *PyObject_GetAttrString_(PyObject *o, const std::string &attr_name)
 {
     const char *attr = attr_name.c_str();
@@ -63,36 +63,34 @@ inline PyObject *PyImport_ImportModule_(const std::string &name)
 // Bytes interface
 #include <bytesobject.h>
 
+PyObject *from_char_to_python_str(const char *in,
+                                  Py_ssize_t size = -1,
+                                  const char *encoding = NULL, /* defaults to latin-1 */
+                                  const char *errors = "strict");
 
-PyObject* from_char_to_python_str(const char* in, Py_ssize_t size=-1,
-                                  const char* encoding=NULL, /* defaults to latin-1 */
-                                  const char* errors="strict");
+PyObject *from_char_to_python_str(const std::string &in,
+                                  const char *encoding = NULL, /* defaults to latin-1 */
+                                  const char *errors = "strict");
 
-PyObject* from_char_to_python_str(const std::string& in,
-                                  const char* encoding=NULL, /* defaults to latin-1 */
-                                  const char* errors="strict");
-
-bopy::object from_char_to_boost_str(const char* in, Py_ssize_t size=-1,
-                                    const char* encoding=NULL, /* defaults to latin-1 */
-                                    const char* errors="strict");
-
-bopy::object from_char_to_boost_str(const std::string& in,
-                                    const char* encoding=NULL, /* defaults to latin-1 */
-                                    const char* errors="strict");
+bopy::object from_char_to_boost_str(const char *in,
+                                    Py_ssize_t size = -1,
+                                    const char *encoding = NULL, /* defaults to latin-1 */
+                                    const char *errors = "strict");
 
+bopy::object from_char_to_boost_str(const std::string &in,
+                                    const char *encoding = NULL, /* defaults to latin-1 */
+                                    const char *errors = "strict");
 
 void throw_bad_type(const char *type, const char *source);
 
-char* from_str_to_char(PyObject* in,
-                       Py_ssize_t* size_out,
-                       const bool utf_encoding=false /* defaults to latin-1 */);
-char* from_str_to_char(const bopy::object& in,
-                       Py_ssize_t* size_out,
-                       const bool utf_encoding=false /* defaults to latin-1 */);
-char* from_str_to_char(PyObject* in);
-char* from_str_to_char(const bopy::object& in);
+char *from_str_to_char(PyObject *in, Py_ssize_t *size_out, const bool utf_encoding = false /* defaults to latin-1 */);
+char *from_str_to_char(const bopy::object &in,
+                       Py_ssize_t *size_out,
+                       const bool utf_encoding = false /* defaults to latin-1 */);
+char *from_str_to_char(PyObject *in);
+char *from_str_to_char(const bopy::object &in);
 
-void view_pybytes_as_char_array(const bopy::object& py_value, Tango::DevVarCharArray& out_array);
+void view_pybytes_as_char_array(const bopy::object &py_value, Tango::DevVarCharArray &out_array);
 
 /// You should run any I/O intensive operations (like requesting data through
 /// the network) in the context of an object like this.
@@ -100,11 +98,10 @@ class AutoPythonAllowThreads
 {
     PyThreadState *m_save;
 
-public:
-
+  public:
     inline void giveup()
     {
-        if (m_save)
+        if(m_save)
         {
             PyEval_RestoreThread(m_save);
             m_save = 0;
@@ -125,9 +122,11 @@ public:
 // Delete a pointer for a CppTango class with Python GIL released.
 // Typically used by boost::shared_ptr constructors as the function
 // to call when the object is deleted.
-struct DeleterWithoutGIL {
+struct DeleterWithoutGIL
+{
     template <typename T>
-    void operator()(T* ptr) {
+    void operator()(T *ptr)
+    {
         AutoPythonAllowThreads guard;
         delete ptr;
     }
@@ -143,7 +142,7 @@ class EnsureOmniThread
 {
     omni_thread::ensure_self *ensure_self;
 
-public:
+  public:
     inline EnsureOmniThread()
     {
         ensure_self = NULL;
@@ -151,26 +150,25 @@ public:
 
     inline void acquire()
     {
-        if (ensure_self == NULL)
+        if(ensure_self == NULL)
         {
-          ensure_self = new omni_thread::ensure_self;
+            ensure_self = new omni_thread::ensure_self;
         }
     }
 
     inline void release()
     {
-        if (ensure_self != NULL)
+        if(ensure_self != NULL)
         {
-          delete ensure_self;
-          ensure_self = NULL;
+            delete ensure_self;
+            ensure_self = NULL;
         }
     }
 
     inline ~EnsureOmniThread()
     {
-      release();
+        release();
     }
-
 };
 
 /**
@@ -182,7 +180,7 @@ inline bool is_omni_thread()
 {
     omni_thread *thread_id = omni_thread::self();
     return (thread_id != NULL);
-};
+}
 
 /**
  * Determines if the given method name exists and is callable
@@ -193,7 +191,7 @@ inline bool is_omni_thread()
  *
  * @return returns true is the method exists or false otherwise
  */
-bool is_method_defined(boost::python::object &obj, const std::string &method_name);
+bool is_method_defined(bopy::object &obj, const std::string &method_name);
 
 /**
  * Determines if the given method name exists and is callable
@@ -216,8 +214,7 @@ bool is_method_defined(PyObject *obj, const std::string &method_name);
  * @param[out] is_method set to true if the symbol exists and is a method
  *             or false otherwise
  */
-void is_method_defined(PyObject *obj, const std::string &method_name,
-                       bool &exists, bool &is_method);
+void is_method_defined(PyObject *obj, const std::string &method_name, bool &exists, bool &is_method);
 
 /**
  * Determines if the given method name exists and is callable
@@ -229,14 +226,10 @@ void is_method_defined(PyObject *obj, const std::string &method_name,
  * @param[out] is_method set to true if the symbol exists and is a method
  *             or false otherwise
  */
-void is_method_defined(boost::python::object &obj, const std::string &method_name,
-                       bool &exists, bool &is_method);
+void is_method_defined(bopy::object &obj, const std::string &method_name, bool &exists, bool &is_method);
 
-#define PYTANGO_MOD \
-    boost::python::object pytango((boost::python::handle<>(boost::python::borrowed(PyImport_AddModule("tango")))));
+#define PYTANGO_MOD bopy::object pytango((bopy::handle<>(bopy::borrowed(PyImport_AddModule("tango")))));
 
-#define CALL_METHOD(retType, self, name, ...) \
-    boost::python::call_method<retType>(self, name , __VA_ARGS__);
+#define CALL_METHOD(retType, self, name, ...) bopy::call_method<retType>(self, name, __VA_ARGS__);
 
-
-bool hasattr(boost::python::object &, const std::string &);
+bool hasattr(bopy::object &, const std::string &);
