@@ -21,18 +21,16 @@
 
 class PyAttr
 {
-public:
+  public:
     /**
      * Constructor
      */
-    PyAttr()
-    {}
+    PyAttr() { }
 
     /**
      * Desctructor
      */
-    virtual ~PyAttr()
-    {}
+    virtual ~PyAttr() { }
 
     /**
      * Read one attribute. This method forward the action to the python method.
@@ -40,7 +38,7 @@ public:
      * @param[in] dev The device on which the attribute has to be read
      * @param[in, out] att the attribute
      */
-    void read(Tango::DeviceImpl *dev,Tango::Attribute &att);
+    void read(Tango::DeviceImpl *dev, Tango::Attribute &att);
 
     /**
      * Write one attribute. This method forward the action to the python method.
@@ -48,7 +46,7 @@ public:
      * @param[in] dev The device on which the attribute has to be written
      * @param[in, out] att the attribute
      */
-    void write(Tango::DeviceImpl *dev,Tango::WAttribute &att);
+    void write(Tango::DeviceImpl *dev, Tango::WAttribute &att);
 
     /**
      * Decide if it is allowed to read/write the attribute
@@ -59,7 +57,7 @@ public:
      * @return a boolean set to true if it is allowed to execute
      *         the command. Otherwise, returns false
      */
-    bool is_allowed(Tango::DeviceImpl *dev,Tango::AttReqType ty);
+    bool is_allowed(Tango::DeviceImpl *dev, Tango::AttReqType ty);
 
     /**
      * Sets the is_allowed method name for this attribute
@@ -98,16 +96,14 @@ public:
      * @param[in] user_prop the AttrProperty vector
      * @param[out] def_prop  the UserDefaultAttrProp instance
      */
-    void set_user_prop(std::vector<Tango::AttrProperty> &user_prop,
-                       Tango::UserDefaultAttrProp &def_prop);
+    void set_user_prop(std::vector<Tango::AttrProperty> &user_prop, Tango::UserDefaultAttrProp &def_prop);
 
     bool _is_method(Tango::DeviceImpl *dev, const std::string &name);
-    
-private:
 
+  private:
     /** the name of the is allowed python method */
     std::string py_allowed_name;
-    
+
     /** the name of the read attribute python method */
     std::string read_name;
 
@@ -118,11 +114,9 @@ private:
 /**
  * The python class representing a scalar attribute
  */
-class PyScaAttr: public Tango::Attr,
-                 public PyAttr
+class PyScaAttr : public Tango::Attr, public PyAttr
 {
-public:
-
+  public:
     /**
      * Python Scalar Attribute constructor
      *
@@ -130,9 +124,10 @@ public:
      * @param[in] _type  The attribute data type
      * @param[in] w The attribute writable type
      */
-    PyScaAttr(const std::string &na, long _type, Tango::AttrWriteType w)
-        : Tango::Attr(na.c_str(), _type, w)
-    {}
+    PyScaAttr(const std::string &na, long _type, Tango::AttrWriteType w) :
+        Tango::Attr(na.c_str(), _type, w)
+    {
+    }
 
     /**
      * Python Scalar Attribute constructor
@@ -143,22 +138,23 @@ public:
      * @param[in] ww The attribute max dim x
      * @param[in] user_prop The attribute user default properties
      */
-    PyScaAttr(const std::string &na, long _type, Tango::AttrWriteType w,
-               std::vector<Tango::AttrProperty> &user_prop)
-        : Tango::Attr(na.c_str(), _type, w)
+    PyScaAttr(const std::string &na, long _type, Tango::AttrWriteType w, std::vector<Tango::AttrProperty> &user_prop) :
+        Tango::Attr(na.c_str(), _type, w)
     {
-        if (user_prop.size() == 0)
+        if(user_prop.size() == 0)
+        {
             return;
+        }
 
         Tango::UserDefaultAttrProp def_prop;
-        set_user_prop(user_prop,def_prop);
+        set_user_prop(user_prop, def_prop);
         set_default_properties(def_prop);
     }
 
     /**
      * Python Scalar Attribute destructor
      */
-    ~PyScaAttr() {};
+    ~PyScaAttr(){};
 
     /**
      * Decide if it is allowed to read/write the attribute
@@ -199,11 +195,9 @@ public:
 
 //------------------------------------------------------------------------------------------------
 
-
-class PySpecAttr: public Tango::SpectrumAttr,
-                  public PyAttr
+class PySpecAttr : public Tango::SpectrumAttr, public PyAttr
 {
-public:
+  public:
     /**
      * Python Spectrum Attribute constructor
      *
@@ -212,9 +206,10 @@ public:
      * @param[in] w The attribute writable type
      * @param[in] xx The attribute max dim x
      */
-    PySpecAttr(const std::string &na, long _type, Tango::AttrWriteType w, long xx)
-        : Tango::SpectrumAttr(na.c_str(), _type, w, xx)
-    {}
+    PySpecAttr(const std::string &na, long _type, Tango::AttrWriteType w, long xx) :
+        Tango::SpectrumAttr(na.c_str(), _type, w, xx)
+    {
+    }
 
     /**
      * Python Spectrum Attribute constructor
@@ -225,23 +220,27 @@ public:
      * @param[in] xx The attribute max dim x
      * @param[in] user_prop The attribute user default properties
      */
-    PySpecAttr(const std::string &na, long _type, Tango::AttrWriteType w, long xx,
-               std::vector<Tango::AttrProperty> &user_prop)
-        : Tango::SpectrumAttr(na.c_str(), _type, w, xx)
+    PySpecAttr(const std::string &na,
+               long _type,
+               Tango::AttrWriteType w,
+               long xx,
+               std::vector<Tango::AttrProperty> &user_prop) :
+        Tango::SpectrumAttr(na.c_str(), _type, w, xx)
     {
-        if (user_prop.size() == 0)
+        if(user_prop.size() == 0)
+        {
             return;
+        }
 
         Tango::UserDefaultAttrProp def_prop;
-        set_user_prop(user_prop,def_prop);
+        set_user_prop(user_prop, def_prop);
         set_default_properties(def_prop);
     }
 
     /**
      * Python Spectrum Attribute destructor
      */
-    ~PySpecAttr()
-    {}
+    ~PySpecAttr() { }
 
     /**
      * Decide if it is allowed to read/write the attribute
@@ -282,10 +281,9 @@ public:
 
 //------------------------------------------------------------------------------------------------
 
-class PyImaAttr: public Tango::ImageAttr,
-                 public PyAttr
+class PyImaAttr : public Tango::ImageAttr, public PyAttr
 {
-public:
+  public:
     /**
      * Python Image Attribute constructor
      *
@@ -295,9 +293,10 @@ public:
      * @param[in] xx The attribute max dim x
      * @param[in] yy The attribute max dim y
      */
-    PyImaAttr(const std::string &na, long _type, Tango::AttrWriteType w, long xx, long yy)
-        : Tango::ImageAttr(na.c_str(), _type, w, xx, yy)
-    {}
+    PyImaAttr(const std::string &na, long _type, Tango::AttrWriteType w, long xx, long yy) :
+        Tango::ImageAttr(na.c_str(), _type, w, xx, yy)
+    {
+    }
 
     /**
      * Python Image Attribute constructor
@@ -309,23 +308,28 @@ public:
      * @param[in] yy The attribute max dim y
      * @param[in] user_prop The attribute user default properties
      */
-    PyImaAttr(const std::string &na, long _type, Tango::AttrWriteType w, long xx, long yy,
-               std::vector<Tango::AttrProperty> &user_prop)
-        : Tango::ImageAttr(na.c_str(), _type, w, xx, yy)
+    PyImaAttr(const std::string &na,
+              long _type,
+              Tango::AttrWriteType w,
+              long xx,
+              long yy,
+              std::vector<Tango::AttrProperty> &user_prop) :
+        Tango::ImageAttr(na.c_str(), _type, w, xx, yy)
     {
-        if (user_prop.size() == 0)
+        if(user_prop.size() == 0)
+        {
             return;
+        }
 
         Tango::UserDefaultAttrProp def_prop;
-        set_user_prop(user_prop,def_prop);
+        set_user_prop(user_prop, def_prop);
         set_default_properties(def_prop);
     }
 
     /**
      * Python Image Attribute destructor
      */
-    ~PyImaAttr()
-    {}
+    ~PyImaAttr() { }
 
     /**
      * Decide if it is allowed to read/write the attribute
