@@ -15,9 +15,9 @@
 #include <boost/python.hpp>
 #include <tango/tango.h>
 
-class CppDeviceClass: public Tango::DeviceClass
+class CppDeviceClass : public Tango::DeviceClass
 {
-public:
+  public:
     CppDeviceClass(const std::string &);
 
     virtual ~CppDeviceClass();
@@ -69,10 +69,12 @@ public:
                           Tango::CmdArgType attr_type,
                           Tango::AttrDataFormat attr_format,
                           Tango::AttrWriteType attr_write,
-                          long dim_x, long dim_y,
+                          long dim_x,
+                          long dim_y,
                           Tango::DispLevel display_level,
                           long polling_period,
-                          bool memorized, bool hw_memorized,
+                          bool memorized,
+                          bool hw_memorized,
                           const std::string &read_method_name,
                           const std::string &write_method_name,
                           const std::string &is_allowed_name,
@@ -88,13 +90,13 @@ public:
      * pipe.
      */
     void create_pipe(std::vector<Tango::Pipe *> &pipe_list,
-		     const std::string &name,
-		     Tango::PipeWriteType access,
-		     Tango::DispLevel display_level,
-		     const std::string &read_method_name,
-		     const std::string &write_method_name,
-		     const std::string &is_allowed_name,
-		     Tango::UserDefaultPipeProp *prop);
+                     const std::string &name,
+                     Tango::PipeWriteType access,
+                     Tango::DispLevel display_level,
+                     const std::string &read_method_name,
+                     const std::string &write_method_name,
+                     const std::string &is_allowed_name,
+                     Tango::UserDefaultPipeProp *prop);
 
     /**
      * Creates a command.
@@ -107,17 +109,17 @@ public:
                         const std::string &param_desc,
                         const std::string &result_desc,
                         Tango::DispLevel display_level,
-                        bool default_command, long polling_period,
+                        bool default_command,
+                        long polling_period,
                         const std::string &is_allowed);
 
-protected:
+  protected:
     PyInterpreterState *interp;
 };
 
 class CppDeviceClassWrap : public CppDeviceClass
 {
-public:
-
+  public:
     /** a reference to itself */
     PyObject *m_self;
 
@@ -186,9 +188,7 @@ public:
      */
     void default_signal_handler(long signo);
 
-
-protected:
-
+  protected:
     /**
      * Initializes the class. Registers as a python DeviceClass to tango,
      * determines existence of a signal handler among other things
