@@ -14,15 +14,12 @@
 
 void export_user_default_fwdattr_prop()
 {
-    boost::python::class_<Tango::UserDefaultFwdAttrProp, boost::noncopyable>("UserDefaultFwdAttrProp")
-        .def("set_label", &Tango::UserDefaultFwdAttrProp::set_label)
-    ;
+    bopy::class_<Tango::UserDefaultFwdAttrProp, boost::noncopyable>("UserDefaultFwdAttrProp")
+        .def("set_label", &Tango::UserDefaultFwdAttrProp::set_label);
 }
 
 void export_fwdattr()
 {
-    boost::python::class_<Tango::FwdAttr, boost::noncopyable>("FwdAttr",
-        boost::python::init<const std::string &, const std::string&>())
-        .def("set_default_properties", &Tango::FwdAttr::set_default_properties)
-    ;
+    bopy::class_<Tango::FwdAttr, boost::noncopyable>("FwdAttr", bopy::init<const std::string &, const std::string &>())
+        .def("set_default_properties", &Tango::FwdAttr::set_default_properties);
 }
