@@ -12,18 +12,15 @@
 #include "precompiled_header.hpp"
 #include "pytgutils.h"
 
-using namespace boost::python;
-
 void export_multi_class_attribute()
 {
-
-    class_<Tango::MultiClassAttribute, boost::noncopyable>("MultiClassAttribute", no_init)
+    bopy::class_<Tango::MultiClassAttribute, boost::noncopyable>("MultiClassAttribute", bopy::no_init)
         .def("get_attr",
-            (Tango::Attr& (Tango::MultiClassAttribute::*) (const std::string &))
-            &Tango::MultiClassAttribute::get_attr,
-            return_value_policy<reference_existing_object>())
-	.def("remove_attr", &Tango::MultiClassAttribute::remove_attr)
-        .def("get_attr_list", &Tango::MultiClassAttribute::get_attr_list,
-            return_value_policy<reference_existing_object>())
-    ;
+             (Tango::Attr & (Tango::MultiClassAttribute::*) (const std::string &) ) &
+                 Tango::MultiClassAttribute::get_attr,
+             bopy::return_value_policy<bopy::reference_existing_object>())
+        .def("remove_attr", &Tango::MultiClassAttribute::remove_attr)
+        .def("get_attr_list",
+             &Tango::MultiClassAttribute::get_attr_list,
+             bopy::return_value_policy<bopy::reference_existing_object>());
 }
