@@ -12,11 +12,9 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_user_default_attr_prop()
 {
-    class_<Tango::UserDefaultAttrProp, boost::noncopyable>("UserDefaultAttrProp")
+    bopy::class_<Tango::UserDefaultAttrProp, boost::noncopyable>("UserDefaultAttrProp")
         .def("set_label", &Tango::UserDefaultAttrProp::set_label)
         .def("set_description", &Tango::UserDefaultAttrProp::set_description)
         .def("set_format", &Tango::UserDefaultAttrProp::set_format)
@@ -66,8 +64,5 @@ void export_user_default_attr_prop()
         .def_readwrite("archive_abs_change", &Tango::UserDefaultAttrProp::archive_abs_change)
         .def_readwrite("archive_rel_change", &Tango::UserDefaultAttrProp::archive_rel_change)
         .def_readwrite("archive_period", &Tango::UserDefaultAttrProp::archive_period)
-        .def_readwrite("enum_labels", &Tango::UserDefaultAttrProp::enum_labels)
-    ;
-
+        .def_readwrite("enum_labels", &Tango::UserDefaultAttrProp::enum_labels);
 }
-
