@@ -12,14 +12,9 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_user_default_pipe_prop()
 {
-    class_<Tango::UserDefaultPipeProp, boost::noncopyable>("UserDefaultPipeProp")
+    bopy::class_<Tango::UserDefaultPipeProp, boost::noncopyable>("UserDefaultPipeProp")
         .def("set_label", &Tango::UserDefaultPipeProp::set_label)
-        .def("set_description", &Tango::UserDefaultPipeProp::set_description)
-    ;
-
+        .def("set_description", &Tango::UserDefaultPipeProp::set_description);
 }
-
