@@ -12,9 +12,7 @@
 #include "precompiled_header.hpp"
 #include <tango/tango.h>
 
-using namespace boost::python;
-
 void export_version()
 {
-    scope().attr("__tangolib_version__") = Tango::TgLibVers;
+    bopy::scope().attr("__tangolib_version__") = Tango::TgLibVers;
 }
