@@ -131,6 +131,7 @@ __all__ = (
     "Device_3Impl",
     "Device_4Impl",
     "Device_5Impl",
+    "Device_6Impl",
     "DispLevel",
     "EncodedAttribute",
     "EnsureOmniThread",
@@ -353,6 +354,7 @@ from ._tango import (
     Device_3Impl,
     Device_4Impl,
     Device_5Impl,
+    Device_6Impl,
     DispLevel,
     EncodedAttribute,
     EnsureOmniThread,
@@ -515,4 +517,4 @@ from .device_proxy import get_device_proxy
 from .pytango_init import init as __init
 
 __init()
-requires_tango("9.5.0", software_name="PyTango")
+requires_tango("10.0.0", software_name="PyTango")
