@@ -171,6 +171,21 @@ def __doc_api_util():
     """,
     )
 
+    document_static_method(
+        ApiUtil,
+        "in_server",
+        """
+    in_server() -> bool
+
+            Returns True if current process is a running Tango device server.
+
+        :returns: running in server
+        :rtype: bool
+
+        .. versionadded:: 10.0.0
+    """,
+    )
+
 
 def api_util_init(doc=True):
     __init_api_util()
