@@ -17,14 +17,16 @@ import collections
 import os
 import types
 import concurrent.futures
+import warnings
+import threading
 
 from asyncio import futures, coroutines
 from asyncio.tasks import ensure_future
-
-from threading import get_ident
+from typing import Callable
 
 # Tango imports
 from tango.green import AbstractExecutor
+from tango.utils import _is_coroutine_function, PyTangoThreadPoolExecutor
 
 __all__ = (
     "AsyncioExecutor",
@@ -33,6 +35,8 @@ __all__ = (
     "_switch_global_executor_to_thread",
 )
 
+_ALREADY_WARNED_FUNCTIONS = []
+
 
 # Function removed from Python 3.11
 # Taken from https://github.com/python/cpython/blob/3.10/Lib/asyncio/coroutines.py
@@ -106,8 +110,19 @@ def run_coroutine_threadsafe(coro, loop):
     return future
 
 
-# Global executor
+_PYTANGOTHREADPOOLEXECUTOR = None
 
+
+def get_thread_pool_executor():
+    global _PYTANGOTHREADPOOLEXECUTOR
+    if _PYTANGOTHREADPOOLEXECUTOR is None:
+        _PYTANGOTHREADPOOLEXECUTOR = PyTangoThreadPoolExecutor(
+            thread_name_prefix="_PyTangoThreadPoolExecutor"
+        )
+    return _PYTANGOTHREADPOOLEXECUTOR
+
+
+# Global executor
 _MAIN_EXECUTOR = None
 _THREAD_EXECUTORS = {}
 
@@ -133,7 +148,7 @@ def get_global_executor():
     # the following patch is used for correct behavior of TestDeviceContext,
     # which has two different executors for main and device threads
     if not _MAIN_EXECUTOR.in_executor_context():
-        ident = get_ident(), os.getpid()
+        ident = threading.get_ident(), os.getpid()
         if ident in _THREAD_EXECUTORS:
             return _THREAD_EXECUTORS[ident]
 
@@ -145,9 +160,16 @@ def set_global_executor(executor):
     _MAIN_EXECUTOR = executor
 
 
+def _get_function_name(fn: Callable) -> str:
+    if hasattr(fn, "__qualname__"):
+        return fn.__qualname__
+    elif hasattr(fn, "__name__"):
+        return fn.__name__
+
+    return f"{fn}"
+
+
 # Asyncio executor
-
-
 class AsyncioExecutor(AbstractExecutor):
     """Asyncio tango executor"""
 
@@ -163,7 +185,9 @@ class AsyncioExecutor(AbstractExecutor):
                 loop = asyncio.new_event_loop()
                 asyncio.set_event_loop(loop)
         self.loop = loop
-        self.subexecutor = subexecutor
+        self.subexecutor = (
+            subexecutor if subexecutor is not None else get_thread_pool_executor()
+        )
 
     def delegate(self, fn, *args, **kwargs):
         """Return the given operation as an asyncio future."""
@@ -180,13 +204,39 @@ class AsyncioExecutor(AbstractExecutor):
 
     def submit(self, fn, *args, **kwargs):
         """Submit an operation"""
-        corofn = _coroutine(lambda: fn(*args, **kwargs))
-        return run_coroutine_threadsafe(corofn(), self.loop)
+        if _is_coroutine_function(fn):
+            return run_coroutine_threadsafe(fn(*args, **kwargs), self.loop)
+        else:
+            # we leave this part of the code to support legacy servers
+            name = _get_function_name(fn)
+            if name not in _ALREADY_WARNED_FUNCTIONS:
+                _ALREADY_WARNED_FUNCTIONS.append(name)
+                warnings.warn(
+                    f"Sync {name} function called: support of "
+                    f"sync functions in PyTango's Asyncio mode is "
+                    f"deprecated. Use 'async def' instead of 'def'.",
+                    DeprecationWarning,
+                )
+            corofn = _coroutine(lambda: fn(*args, **kwargs))
+            return run_coroutine_threadsafe(corofn(), self.loop)
 
     def execute(self, fn, *args, **kwargs):
         """Execute an operation and return the result."""
         if self.in_executor_context():
-            corofn = _coroutine(lambda: fn(*args, **kwargs))
-            return corofn()
+            if _is_coroutine_function(fn):
+                return fn(*args, **kwargs)
+            else:
+                # we leave this part of the code to support legacy servers
+                name = _get_function_name(fn)
+                if name not in _ALREADY_WARNED_FUNCTIONS:
+                    _ALREADY_WARNED_FUNCTIONS.append(name)
+                    warnings.warn(
+                        f"Sync {name} function called: support of "
+                        f"sync functions in PyTango's Asyncio mode is "
+                        f"deprecated. Use 'async def' instead of 'def'.",
+                        DeprecationWarning,
+                    )
+                corofn = _coroutine(lambda: fn(*args, **kwargs))
+                return corofn()
         future = self.submit(fn, *args, **kwargs)
         return future.result()
