@@ -32,6 +32,7 @@ from tango.utils import seq_2_StdStringVector, seq_2_DbData, DbData_2_dict
 from tango.utils import is_pure_str, is_non_str_seq
 from tango.utils import _get_device_fqtrl_if_necessary
 from tango.green import green, get_green_mode
+from tango.utils import _trace_client
 from tango.device_proxy import __init_device_proxy_internals as init_device_proxy
 
 __all__ = ("AttributeProxy", "attribute_proxy_init", "get_attribute_proxy")
@@ -304,6 +305,7 @@ class AttributeProxy:
     python reimplementation of the AttributeProxy found on the C++ API.
     """
 
+    @_trace_client
     def __init__(self, *args, **kwds):
         green_mode = kwds.pop("green_mode", get_green_mode())
         # If TestContext active, short TRL is replaced with fully-qualified
@@ -385,6 +387,7 @@ def _method_dev_and_name(dp_fn_name, doc=True):
             + str(getattr(DeviceProxy, dp_fn_name).__doc__)
         )
     __new_fn.__name__ = dp_fn_name
+    __new_fn.__qualname__ = f"AttributeProxy.{dp_fn_name}"
     return __new_fn
 
 
@@ -404,6 +407,7 @@ def _method_device(dp_fn_name, doc=True):
             + str(getattr(DeviceProxy, dp_fn_name).__doc__)
         )
     __new_fn.__name__ = dp_fn_name
+    __new_fn.__qualname__ = f"AttributeProxy.{dp_fn_name}"
     return __new_fn
 
 
@@ -414,6 +418,7 @@ def _method_attribute(dp_fn_name, doc=True):
     if doc:
         __new_fn.__doc__ = getattr(_AttributeProxy, dp_fn_name).__doc__
     __new_fn.__name__ = dp_fn_name
+    __new_fn.__qualname__ = f"AttributeProxy.{dp_fn_name}"
     return __new_fn
 
 
@@ -435,9 +440,15 @@ def __init_AttributeProxy(doc=True):
     )
 
     # Property methods
-    AttributeProxy.get_property = _method_attribute("get_property", doc=doc)
-    AttributeProxy.put_property = _method_attribute("put_property", doc=doc)
-    AttributeProxy.delete_property = _method_attribute("delete_property", doc=doc)
+    AttributeProxy.get_property = _trace_client(
+        _method_attribute("get_property", doc=doc)
+    )
+    AttributeProxy.put_property = _trace_client(
+        _method_attribute("put_property", doc=doc)
+    )
+    AttributeProxy.delete_property = _trace_client(
+        _method_attribute("delete_property", doc=doc)
+    )
 
     # Attribute methods
     AttributeProxy.get_config = _method_dev_and_name("get_attribute_config", doc=doc)
