@@ -407,7 +407,7 @@ def __doc_base_types():
     document_enum(
         "CmdArgType",
         """
-    An enumeration representing the command argument type.
+    An enumeration representing the Tango data types.
 
         - DevVoid
         - DevBoolean
@@ -572,7 +572,6 @@ def __doc_base_types():
     An enumeration representing event type
 
         - CHANGE_EVENT
-        - QUALITY_EVENT
         - PERIODIC_EVENT
         - ARCHIVE_EVENT
         - USER_EVENT
@@ -580,10 +579,13 @@ def __doc_base_types():
         - DATA_READY_EVENT
         - INTERFACE_CHANGE_EVENT
         - PIPE_EVENT
+        - ALARM_EVENT
 
-        *DATA_READY_EVENT - New in PyTango 7.0.0*
-        *INTERFACE_CHANGE_EVENT - New in PyTango 9.2.2*
-        *PIPE_EVENT - New in PyTango 9.2.2*
+        .. versionchanged:: 7.0.0 Added DATA_READY_EVENT
+        .. versionchanged:: 9.2.2 Added INTERFACE_CHANGE_EVENT
+        .. versionchanged:: 9.2.2 Added PIPE_EVENT
+        .. versionchanged:: 10.0.0 Added ALARM_EVENT
+        .. versionchanged:: 10.0.0 Removed QUALITY_EVENT
 
     """,
     )
@@ -754,14 +756,16 @@ def __doc_base_types():
         - Synchronous
         - Futures
         - Gevent
+        - Asyncio
 
-    New in PyTango 8.1.0
+    .. versionadded:: 8.1.0
+    .. versionchanged:: 8.1.9 Added Asyncio
     """,
     )
 
     ArchiveEventInfo.__doc__ = """
     A structure containing available archiving event information for an attribute
-    with the folowing members:
+    with the following members:
 
         - archive_rel_change : (str) relative change that will generate an event
         - archive_abs_change : (str) absolute change that will generate an event
@@ -830,7 +834,7 @@ def __doc_base_types():
 
     AttributeAlarmInfo.__doc__ = """
     A structure containing available alarm information for an attribute
-    with the folowing members:
+    with the following members:
 
         - min_alarm : (str) low alarm level
         - max_alarm : (str) high alarm level
@@ -849,7 +853,7 @@ def __doc_base_types():
 
     AttributeEventInfo.__doc__ = """
     A structure containing available event information for an attribute
-    with the folowing members:
+    with the following members:
 
         - ch_event : (ChangeEventInfo) change event information
         - per_event : (PeriodicEventInfo) periodic event information
@@ -943,7 +947,7 @@ def __doc_base_types():
 
     ChangeEventInfo.__doc__ = """
     A structure containing available change event information for an attribute
-    with the folowing members:
+    with the following members:
 
         - rel_change : (str) relative change that will generate an event
         - abs_change : (str) absolute change that will generate an event
@@ -951,7 +955,7 @@ def __doc_base_types():
 
     PeriodicEventInfo.__doc__ = """
     A structure containing available periodic event information for an attribute
-    with the folowing members:
+    with the following members:
 
         - period : (str) event period
         - extensions : (StdStringVector) extensions (currently not used)"""
@@ -1008,10 +1012,15 @@ def __doc_base_types():
         - server_id : (str) server ID
         - server_host : (str) host name
         - server_version : (str) server version
-        - doc_url : (str) document url"""
+        - doc_url : (str) document url
+        - version_info : (dict<str, str>) version info dict
+
+    .. versionchanged:: 10.0.0
+        Added `version_info` field
+    """
 
     LockerInfo.__doc__ = """
-    A structure with information about the locker with the folowing members:
+    A structure with information about the locker with the following members:
 
         - ll : (tango.LockerLanguage) the locker language
         - li : (pid_t / UUID) the locker id
@@ -1023,7 +1032,7 @@ def __doc_base_types():
         New in PyTango 7.0.0"""
 
     PollDevice.__doc__ = """
-    A structure containing PollDevice information with the folowing members:
+    A structure containing PollDevice information with the following members:
 
         - dev_name : (str) device name
         - ind_list : (sequence<int>) index list
