@@ -31,6 +31,7 @@ from tango._tango import (
 )
 from tango.utils import document_method as __document_method
 from tango.utils import document_static_method as __document_static_method
+from tango.utils import _trace_client
 from tango.green import green
 
 
@@ -59,7 +60,13 @@ def __get_command_inout_param(self, cmd_name, cmd_param=None):
         # DeviceProxy only.
         info = self.command_query(cmd_name)
         param = DeviceData()
-        param.insert(info.in_type, cmd_param)
+        try:
+            param.insert(info.in_type, cmd_param)
+        except TypeError as err:
+            raise TypeError(
+                f"Invalid input argument for command {cmd_name}: "
+                f"{cmd_param!r} cannot be converted to type {info.in_type}"
+            ) from err
         return param
     elif isinstance(self, Database):
         # I just try to guess types DevString and DevVarStringArray
@@ -91,7 +98,7 @@ def __Connection__command_inout(self, name, *args, **kwds):
                 - cmd_name  : (str) Command name.
                 - cmd_param : (any) It should be a value of the type expected by the
                               command or a DeviceData object with this value inserted.
-                              It can be ommited if the command should not get any argument.
+                              It can be omitted if the command should not get any argument.
                 - green_mode : (GreenMode) Defaults to the current DeviceProxy GreenMode.
                                (see :meth:`~tango.DeviceProxy.get_green_mode` and
                                :meth:`~tango.DeviceProxy.set_green_mode`).
@@ -107,11 +114,16 @@ def __Connection__command_inout(self, name, *args, **kwds):
         Throws     : ConnectionFailed, CommunicationFailed, DeviceUnlocked, DevFailed from device
                      TimeoutError (green_mode == Futures) If the future didn't finish executing before the given timeout.
                      Timeout (green_mode == Gevent) If the async result didn't finish executing before the given timeout.
+                     TypeError if cmd_param's type is not compatible with the command.
 
     .. versionadded:: 8.1.0
         *green_mode* parameter.
         *wait* parameter.
         *timeout* parameter.
+
+    .. versionchanged:: 10.0.0
+        TypeError's for invalid command input arguments are now more detailed.
+        For commands with a DEV_STRING input argument, invalid data will now raise TypeError instead of SystemError.
     """
     r = Connection.command_inout_raw(self, name, *args, **kwds)
     if isinstance(r, DeviceData):
@@ -136,10 +148,15 @@ def __Connection__command_inout_raw(self, cmd_name, cmd_param=None):
                 - cmd_name  : (str) Command name.
                 - cmd_param : (any) It should be a value of the type expected by the
                               command or a DeviceData object with this value inserted.
-                              It can be ommited if the command should not get any argument.
+                              It can be omitted if the command should not get any argument.
         Return     : A DeviceData object.
 
-        Throws     : ConnectionFailed, CommunicationFailed, DeviceUnlocked, DevFailed from device
+        Throws     : ConnectionFailed, CommunicationFailed, DeviceUnlocked, DevFailed from device.
+                     TypeError if cmd_param's type is not compatible with the command.
+
+    .. versionchanged:: 10.0.0
+        TypeError's for invalid command input arguments are now more detailed.
+        For commands with a DEV_STRING input argument, invalid data will now raise TypeError instead of SystemError.
     """
     param = __get_command_inout_param(self, cmd_name, cmd_param)
     return self.__command_inout(cmd_name, param)
@@ -157,7 +174,7 @@ def __Connection__command_inout_asynch(self, cmd_name, *args):
                 - cmd_name  : (str) Command name.
                 - cmd_param : (any) It should be a value of the type expected by the
                               command or a DeviceData object with this value inserted.
-                              It can be ommited if the command should not get any argument.
+                              It can be omitted if the command should not get any argument.
                               If the command should get no argument and you want
                               to set the 'forget' param, use None for cmd_param.
                 - forget    : (bool) If this flag is set to true, this means that the client
@@ -181,7 +198,7 @@ def __Connection__command_inout_asynch(self, cmd_name, *args):
                 - cmd_name  : (str) Command name.
                 - cmd_param : (any)It should be a value of the type expected by the
                               command or a DeviceData object with this value inserted.
-                              It can be ommited if the command should not get any argument.
+                              It can be omitted if the command should not get any argument.
                 - callback  : Any callable object (function, lambda...) or any oject
                               with a method named "cmd_ended".
         Return     : None
@@ -193,6 +210,10 @@ def __Connection__command_inout_asynch(self, cmd_name, *args):
         to use the **push** model (the one with the callback parameter), you
         need to change the global TANGO model to PUSH_CALLBACK.
         You can do this with the :meth:`tango.ApiUtil.set_asynch_cb_sub_model`
+
+    .. versionchanged:: 10.0.0
+        TypeError's for invalid command input arguments are now more detailed.
+        For commands with a DEV_STRING input argument, invalid data will now raise TypeError instead of SystemError.
     """
     if len(args) == 0:  # command_inout_asynch()
         argin = DeviceData()
@@ -280,9 +301,9 @@ __Connection__command_inout_reply.__name__ = "command_inout_reply"
 def __init_Connection():
     Connection.defaultCommandExtractAs = ExtractAs.Numpy
     Connection.command_inout_raw = __Connection__command_inout_raw
-    Connection.command_inout = green(__Connection__command_inout)
-    Connection.command_inout_asynch = __Connection__command_inout_asynch
-    Connection.command_inout_reply = __Connection__command_inout_reply
+    Connection.command_inout = green(_trace_client(__Connection__command_inout))
+    Connection.command_inout_asynch = _trace_client(__Connection__command_inout_asynch)
+    Connection.command_inout_reply = _trace_client(__Connection__command_inout_reply)
 
 
 def __doc_Connection():
