@@ -35,6 +35,7 @@ from tango._tango import (
 )
 
 from tango.utils import (
+    _trace_client,
     is_pure_str,
     is_non_str_seq,
     seq_2_StdStringVector,
@@ -95,6 +96,10 @@ def __init_DbDatum():
 # -~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-~-
 
 
+def __Database____init__(self, *args, **kwargs):
+    return Database.__init_orig__(self, *args, **kwargs)
+
+
 def __Database__add_server(self, servname, dev_info, with_dserver=False):
     """
     add_server( self, servname, dev_info, with_dserver=False) -> None
@@ -206,8 +211,7 @@ def __Database__export_server(self, dev_info):
     self._export_server(dev_info)
 
 
-def __Database__generic_get_property(self, obj_name, value, f):
-    """internal usage"""
+def __generic_get_property(obj_name, value, f):
     ret = None
     if isinstance(value, DbData):
         new_value = value
@@ -242,6 +246,14 @@ def __Database__generic_get_property(self, obj_name, value, f):
     f(obj_name, new_value)
     if ret is None:
         ret = {}
+
+    return new_value, ret
+
+
+def __Database__generic_get_property(self, obj_name, value, f):
+    """internal usage"""
+
+    new_value, ret = __generic_get_property(obj_name, value, f)
     return DbData_2_dict(new_value, ret)
 
 
@@ -288,37 +300,8 @@ def __Database__generic_delete_property(self, obj_name, value, f):
 
 def __Database__generic_get_attr_pipe_property(self, obj_name, value, f):
     """internal usage for class or device attribute and pipe properties."""
-    if isinstance(value, DbData):
-        new_value = value
-    elif isinstance(value, DbDatum):
-        new_value = DbData()
-        new_value.append(value)
-    elif is_pure_str(value):
-        new_value = DbData()
-        new_value.append(DbDatum(value))
-    elif isinstance(value, collections.abc.Sequence):
-        new_value = DbData()
-        for e in value:
-            if isinstance(e, DbDatum):
-                new_value.append(e)
-            else:
-                new_value.append(DbDatum(str(e)))
-    elif isinstance(value, collections.abc.Mapping):
-        new_value = DbData()
-        for k, v in value.items():
-            if isinstance(v, DbDatum):
-                new_value.append(v)
-            else:
-                new_value.append(DbDatum(k))
-    else:
-        raise TypeError(
-            "Value must be a string, tango.DbDatum, "
-            "tango.DbData, a sequence or a dictionary"
-        )
 
-    f(obj_name, new_value)
-
-    ret = {}
+    new_value, ret = __generic_get_property(obj_name, value, f)
     nb_items = len(new_value)
     i = 0
     while i < nb_items:
@@ -370,25 +353,22 @@ def __Database__generic_put_attr_pipe_property(self, obj_name, value, f):
 def __Database__generic_delete_attr_pipe_property(self, obj_name, value, f):
     """internal usage for class or device attribute and pipe properties."""
     if isinstance(value, DbData):
-        new_value = value
+        f(obj_name, value)
     elif is_non_str_seq(value):
-        new_value = seq_2_DbData(value)
+        f(obj_name, seq_2_DbData(value))
     elif isinstance(value, collections.abc.Mapping):
-        new_value = DbData()
-        for k1, v1 in value.items():
-            attr = DbDatum(k1)
-            attr.append(str(len(v1)))
-            new_value.append(attr)
-            for k2 in v1:
-                new_value.append(DbDatum(k2))
+        for attr_pipe_name, properties in value.items():
+            new_value = DbData()
+            new_value.append(DbDatum(attr_pipe_name))
+            for prop in properties:
+                new_value.append(DbDatum(prop))
+            f(obj_name, new_value)
     else:
         raise TypeError(
             "Value must be a string, tango.DbDatum, "
             "tango.DbData, a sequence or a dictionary"
         )
 
-    return f(obj_name, new_value)
-
 
 def __Database__put_property(self, obj_name, value):
     """
@@ -735,7 +715,7 @@ def __Database__delete_device_attribute_property(self, dev_name, value):
                 1. DbData [in] - several property data to be deleted
                 2. sequence<str> [in]- several property data to be deleted
                 3. sequence<DbDatum> [in] - several property data to be deleted
-                3. dict<str, seq<str>> keys are attribute names and value being a list of attribute property names
+                3. dict<str, seq<str>> with each key an attribute name and the value a list of attribute property names to delete from that attribute
 
         Return     : None
 
@@ -758,7 +738,7 @@ def __Database__delete_device_pipe_property(self, dev_name, value):
                 1. DbData [in] - several property data to be deleted
                 2. sequence<str> [in]- several property data to be deleted
                 3. sequence<DbDatum> [in] - several property data to be deleted
-                3. dict<str, seq<str>> keys are pipe names and value being a list of pipe property names
+                3. dict<str, seq<str>> with each key a pipe name and the value a list of pipe property names to delete from that pipe
 
         Return     : None
 
@@ -1048,36 +1028,60 @@ def __Database__str(self):
 
 
 def __init_Database():
-    Database.add_server = __Database__add_server
-    Database.export_server = __Database__export_server
-    Database.put_property = __Database__put_property
-    Database.get_property = __Database__get_property
-    Database.get_property_forced = __Database__get_property_forced
-    Database.delete_property = __Database__delete_property
-    Database.get_device_property = __Database__get_device_property
-    Database.put_device_property = __Database__put_device_property
-    Database.delete_device_property = __Database__delete_device_property
-    Database.get_device_property_list = __Database__get_device_property_list
-    Database.get_device_attribute_property = __Database__get_device_attribute_property
-    Database.get_device_pipe_property = __Database__get_device_pipe_property
-    Database.put_device_attribute_property = __Database__put_device_attribute_property
-    Database.put_device_pipe_property = __Database__put_device_pipe_property
-    Database.delete_device_attribute_property = (
+    Database.__init_orig__ = Database.__init__
+    Database.__init__ = _trace_client(__Database____init__)
+    Database.add_server = _trace_client(__Database__add_server)
+    Database.export_server = _trace_client(__Database__export_server)
+    Database.put_property = _trace_client(__Database__put_property)
+    Database.get_property = _trace_client(__Database__get_property)
+    Database.get_property_forced = _trace_client(__Database__get_property_forced)
+    Database.delete_property = _trace_client(__Database__delete_property)
+    Database.get_device_property = _trace_client(__Database__get_device_property)
+    Database.put_device_property = _trace_client(__Database__put_device_property)
+    Database.delete_device_property = _trace_client(__Database__delete_device_property)
+    Database.get_device_property_list = _trace_client(
+        __Database__get_device_property_list
+    )
+    Database.get_device_attribute_property = _trace_client(
+        __Database__get_device_attribute_property
+    )
+    Database.get_device_pipe_property = _trace_client(
+        __Database__get_device_pipe_property
+    )
+    Database.put_device_attribute_property = _trace_client(
+        __Database__put_device_attribute_property
+    )
+    Database.put_device_pipe_property = _trace_client(
+        __Database__put_device_pipe_property
+    )
+    Database.delete_device_attribute_property = _trace_client(
         __Database__delete_device_attribute_property
     )
-    Database.delete_device_pipe_property = __Database__delete_device_pipe_property
-    Database.get_class_property = __Database__get_class_property
-    Database.put_class_property = __Database__put_class_property
-    Database.delete_class_property = __Database__delete_class_property
-    Database.get_class_attribute_property = __Database__get_class_attribute_property
-    Database.get_class_pipe_property = __Database__get_class_pipe_property
-    Database.put_class_attribute_property = __Database__put_class_attribute_property
-    Database.put_class_pipe_property = __Database__put_class_pipe_property
-    Database.delete_class_attribute_property = (
+    Database.delete_device_pipe_property = _trace_client(
+        __Database__delete_device_pipe_property
+    )
+    Database.get_class_property = _trace_client(__Database__get_class_property)
+    Database.put_class_property = _trace_client(__Database__put_class_property)
+    Database.delete_class_property = _trace_client(__Database__delete_class_property)
+    Database.get_class_attribute_property = _trace_client(
+        __Database__get_class_attribute_property
+    )
+    Database.get_class_pipe_property = _trace_client(
+        __Database__get_class_pipe_property
+    )
+    Database.put_class_attribute_property = _trace_client(
+        __Database__put_class_attribute_property
+    )
+    Database.put_class_pipe_property = _trace_client(
+        __Database__put_class_pipe_property
+    )
+    Database.delete_class_attribute_property = _trace_client(
         __Database__delete_class_attribute_property
     )
-    Database.delete_class_pipe_property = __Database__delete_class_pipe_property
-    Database.get_service_list = __Database__get_service_list
+    Database.delete_class_pipe_property = _trace_client(
+        __Database__delete_class_pipe_property
+    )
+    Database.get_service_list = _trace_client(__Database__get_service_list)
     Database.__str__ = __Database__str
     Database.__repr__ = __Database__str
 
@@ -1096,19 +1100,19 @@ def __doc_Database():
 
     The constructor uses the TANGO_HOST env. variable to determine which
     instance of the Database to connect to.
-    
+
     If TANGO_HOST env is not set, or you want to connect to a specific database, you can provide host and port to constructor:
-    
+
          db = Database(host: str, port: int)
-             
+
          or:
-             
+
          db = Database(host: str, port: str)
-         
+
     Alternatively, it is possible to start Database using file instead of a real database:
-    
+
         db = Database(filename: str)
-        
+
     """
 
     document_method(
