@@ -304,10 +304,10 @@ def __DeviceClass__init__(self, name):
                     pu.get_property_values(prop_name, self.class_property_list),
                 )
     except DevFailed as df:
-        print(f"PyDS: {name}: A Tango error occured in the constructor:")
+        print(f"PyDS: {name}: A Tango error occurred in the constructor:")
         Except.print_exception(df)
     except Exception as e:
-        print(f"PyDS: {name}: An error occured in the constructor:")
+        print(f"PyDS: {name}: An error occurred in the constructor:")
         print(str(e))
 
 
@@ -589,6 +589,8 @@ def __create_command(self, deviceimpl_class, cmd_name, cmd_info):
                         "is not an string" % (cmd_name, name)
                     )
                     __throw_create_command_exception(msg)
+            elif info_name_lower == "is allowed green_mode":
+                pass
             else:
                 msg = (
                     f"Wrong data type in command information for command {cmd_name} in "
@@ -1045,10 +1047,10 @@ def __doc_DeviceClass():
         """
     get_class_attr(self) -> None
 
-        Returns the instance of the :class:`tango.MultiClassAttribute` for the class 
+        Returns the instance of the :class:`tango.MultiClassAttribute` for the class
 
         :param: None
-        
+
         :returns: the instance of the :class:`tango.MultiClassAttribute` for the class
         :rtype: :class:`tango.MultiClassAttribute`
     """,
@@ -1059,7 +1061,7 @@ def __doc_DeviceClass():
         """
     get_pipe_list(self, dev_name) -> None
 
-        Returns the list of pipes for the specified device 
+        Returns the list of pipes for the specified device
 
         :param atr dev_name: name of the device
 
@@ -1073,10 +1075,10 @@ def __doc_DeviceClass():
         """
     get_pipe_by_name(self, pipe_name, dev_name) -> None
 
-        Returns the :class:`Pipe` instance with name <pipe_name> for the specified device 
+        Returns the :class:`Pipe` instance with name <pipe_name> for the specified device
 
         :param str pipe_name: name of the pipe
-        
+
         :param str dev_name: name of the device
 
         :returns: :class:`tango.server.pipe` object
