@@ -23,6 +23,7 @@ from tango._tango import __Group as _RealGroup
 from tango.utils import seq_2_StdStringVector, is_non_str_seq, is_pure_str
 from tango.utils import document_method as __document_method
 from tango.utils import _get_device_fqtrl_if_necessary
+from tango.utils import _trace_client
 from tango.device_proxy import __init_device_proxy_internals as init_device_proxy
 
 
@@ -133,6 +134,7 @@ class Group:
     def __repr__(self):
         return "Group(%s)" % self.get_name()
 
+    @_trace_client
     def command_inout(self, cmd_name, param=None, forward=True):
         if param is None:
             idx = self.command_inout_asynch(cmd_name, forget=False, forward=forward)
@@ -142,14 +144,17 @@ class Group:
             )
         return self.command_inout_reply(idx)
 
+    @_trace_client
     def read_attribute(self, attr_name, forward=True):
         idx = self.__group.read_attribute_asynch(attr_name, forward)
         return self.__group.read_attribute_reply(idx)
 
+    @_trace_client
     def read_attributes(self, attr_names, forward=True):
         idx = self.__group.read_attributes_asynch(attr_names, forward)
         return self.__group.read_attributes_reply(idx)
 
+    @_trace_client
     def write_attribute(self, attr_name, value, forward=True, multi=False):
         idx = self.__group.write_attribute_asynch(
             attr_name, value, forward=forward, multi=multi
@@ -190,7 +195,8 @@ def __init_proxy_Group():
             return getattr(self._Group__group, fname)(*args, **kwds)
 
         fn.__doc__ = getattr(_RealGroup, fname).__doc__
-        setattr(Group, fname, fn)
+        fn.__qualname__ = f"Group.{fname}"
+        setattr(Group, fname, _trace_client(fn))
 
     for fname in proxy_methods:
         proxy_call_define(fname)
