@@ -31,6 +31,7 @@ from tango._tango import (
     DbDevInfo,
     EnsureOmniThread,
     is_omni_thread,
+    _telemetry,
 )
 from tango.utils import document_method as __document_method
 from tango.utils import document_static_method as __document_static_method
@@ -521,10 +522,10 @@ def __doc_Util():
            this method prints a message and aborts the device server process.
 
        :param bool exit: exit or throw DevFailed
-       
+
        :returns: the tango :class:`Util` object
        :rtype: :class:`Util`
-       
+
        :raises: :class:`DevFailed` instead of aborting if exit is set to False
     """,
     )
@@ -535,11 +536,11 @@ def __doc_Util():
     init(*args) -> Util
 
        Static method that creates and gets the singleton object reference.
-       This method returns a reference to the object of the Util class. 
+       This method returns a reference to the object of the Util class.
        If the class singleton object has not been created, it will be instantiated
 
        :param str \\*args: the process commandline arguments
-       
+
        :return: :class:`Util` the tango Util object
        :rtype: :class:`Util`
     """,
@@ -554,7 +555,7 @@ def __doc_Util():
 
         :param device: :class:`tango.LatestDeviceImpl` device object
         :type device: :class:`tango.LatestDeviceImpl`
-        
+
         :return: the associated CORBA object reference
         :rtype: str
     """,
@@ -1131,13 +1132,18 @@ def __doc_Util():
     #
     # """)
 
-    # TODO finish documentation
-    # document_static_method("set_use_db", """
-    # set_use_db(self) -> None
-    #
-    #     TODO DOCU
-    #
-    # """)
+    document_static_method(
+        "set_use_db",
+        """
+    set_use_db(self) -> None
+
+       Set the database use Tango::Util::_UseDb flag.
+       Implemented for device server started without database usage.
+
+       Use with extreme care!
+
+    """,
+    )
 
     document_method(
         "server_cleanup",
@@ -1146,13 +1152,51 @@ def __doc_Util():
 
         Release device server resources (EXPERT FEATURE!)
 
-        This method cleans up the Tango device server and relinquishes 
+        This method cleans up the Tango device server and relinquishes
         all computer resources before the process exits.  It is
-        unnecessary to call this, unless Util.server_run has been bypassed. 
+        unnecessary to call this, unless Util.server_run has been bypassed.
 
     """,
     )
 
+    document_method(
+        "is_auto_alarm_on_change_event",
+        """
+    is_auto_alarm_on_change_event(self) -> bool
+
+        Returns True if alarm events are automatically pushed to subscribers when a device
+        pushes a change event, and the attribute quality has changed to or from alarm.
+
+        Can be configured in two ways:
+
+          - via the ``CtrlSystem`` free Tango database property
+            ``AutoAlarmOnChangeEvent`` (set to true or false),
+          - by calling the :meth:`tango.Util.set_auto_alarm_on_change_event`.
+
+        Parameters : None
+        Return     : bool
+
+        .. versionadded:: 10.0.0
+    """,
+    )
+
+    document_method(
+        "set_auto_alarm_on_change_event",
+        """
+    set_auto_alarm_on_change_event(self, bool) -> None
+
+        Toggles if alarm events are automatically pushed - see
+        :meth:`tango.Util.is_auto_alarm_on_change_event`.
+
+        This method takes priority over the value of the free property in the Tango database.
+
+        Parameters : bool
+        Return     : None
+
+        .. versionadded:: 10.0.0
+    """,
+    )
+
 
 #
 # EnsureOmniThread context handler
@@ -1164,8 +1208,9 @@ def __EnsureOmniThread__enter__(self):
     return self
 
 
-def __EnsureOmniThread__exit__(self, *args, **kwargs):
+def __EnsureOmniThread__exit__(self, exc_type, exc_value, traceback):
     self._release()
+    return False
 
 
 def __init_EnsureOmniThread():
@@ -1180,20 +1225,20 @@ def __doc_EnsureOmniThread():
     that will interact with Tango must guard these threads within this
     Python context.  This is especially important when working with
     event subscriptions, and pushing events.
-    
+
     This context handler class ensures a non-omniORB thread will still
     get a dummy omniORB thread ID - cppTango requires threads to
     be identifiable in this way.  It should only be acquired once for
     the lifetime of the thread, and must be released before the thread
     is cleaned up.
-        
+
     Here is an example::
 
         import tango
         from threading import Thread
         from time import sleep
-        
-        
+
+
         def my_thread_run():
             with tango.EnsureOmniThread():
                 eid = dp.subscribe_event(
@@ -1202,8 +1247,8 @@ def __doc_EnsureOmniThread():
                     print(f"num events stored {len(cb.get_events())}")
                     sleep(1)
                 dp.unsubscribe_event(eid)
-        
-    
+
+
         cb = tango.utils.EventCallback()  # print events to stdout
         dp = tango.DeviceProxy("sys/tg_test/1")
         dp.poll_attribute("double_scalar", 1000)
@@ -1213,7 +1258,7 @@ def __doc_EnsureOmniThread():
         sleep(5)
         running = False
         thread.join()
-        
+
     .. versionadded:: 9.3.2
     """
 
@@ -1233,10 +1278,54 @@ def __doc_is_omni_thread():
     """
 
 
+#
+# TraceContextScope context handler
+#
+
+
+def __TraceContextScope__enter__(self):
+    self._acquire()
+    return self
+
+
+def __TraceContextScope__exit__(self, exc_type, exc_value, traceback):
+    self._release()
+    return False
+
+
+def __init_TraceContextScope():
+    _telemetry.TraceContextScope.__enter__ = __TraceContextScope__enter__
+    _telemetry.TraceContextScope.__exit__ = __TraceContextScope__exit__
+
+
+def __doc_TraceContextScope():
+    _telemetry.TraceContextScope.__doc__ = """\
+
+    Internal - for telemetry tracing purposes.
+
+    Used to propagate the Python OpenTelemetry context to the cppTango telemetry context.
+    When the context handler is entered, a new span is created.  During this process, the
+    the current cppTango context is stored before the new span is set as the active scope.
+    When the context handler exists, the span ends and the old context is restored at the
+    C++ level.
+
+    trace_parent and trace_state strings encoded as per the W3C standard: https://www.w3.org/TR/trace-context/
+
+    with tango._telemetry.TraceContextScope(new_span_name, trace_parent, trace_state):
+        x = proxy.read_attribute("foo")
+
+    This is a no-op if telemetry support isn't compiled into cppTango (check tango.constants.TANGO_USE_TELEMETRY)
+
+    .. versionadded:: 10.0.0
+    """
+
+
 def pyutil_init(doc=True):
     __init_Util()
     __init_EnsureOmniThread()
+    __init_TraceContextScope()
     if doc:
         __doc_Util()
         __doc_EnsureOmniThread()
         __doc_is_omni_thread()
+        __doc_TraceContextScope()
