@@ -11,22 +11,20 @@
 
 """Server helper classes for writing Tango device servers."""
 
-
 import sys
 import copy
-from inspect import getfullargspec
 import inspect
 import logging
 import functools
 import traceback
-import asyncio
 import warnings
-import threading
 
-from tango._tango import AttrDataFormat, AttrWriteType, PipeWriteType
-from tango._tango import DevFailed, GreenMode, SerialModel, ApiUtil
+from typing import Union, ClassVar
+from inspect import getfullargspec
+
+from tango._tango import AttrDataFormat, AttrWriteType, PipeWriteType, DevState
+from tango._tango import DevFailed, GreenMode, SerialModel
 
-from tango.utils import PyTangoUserWarning
 from tango.attr_data import AttrData
 from tango.pipe_data import PipeData
 from tango.device_class import DeviceClass
@@ -40,15 +38,21 @@ from tango.utils import (
     is_seq,
     is_non_str_seq,
     is_pure_str,
+    _is_coroutine_function,
     get_tango_type_format,
     get_attribute_type_format,
     set_complex_value,
     parse_type_hint,
+    _create_device_telemetry_tracer,
+    get_telemetry_tracer_provider_factory,
+    _force_tracing,
+    _forcefully_traced_method,
 )
 from tango.utils import scalar_to_array_type
 from tango.green import get_green_mode, get_executor
 from tango.pyutil import Util
 from tango.asyncio_executor import AsyncioExecutor
+from tango.constants import StatusNotSet
 
 __all__ = (
     "DeviceMeta",
@@ -68,84 +72,6 @@ API_VERSION = 2
 
 # Helpers
 
-_debug_run_active = False
-try:
-    import pydevd
-
-    _debugger = pydevd.get_global_debugger()
-    _disabled_via_env_var = ApiUtil.get_env_var("PYTANGO_DISABLE_DEBUG_TRACE_PATCHING")
-    if _debugger is not None and not _disabled_via_env_var:
-        _debug_run_active = True
-        warnings.warn(
-            "pydevd debugger detected: tango.server.Device methods "
-            "will be patched for tracing.",
-            category=PyTangoUserWarning,
-        )
-except Exception:
-    pass
-
-
-_coverage_run_active = False
-
-try:
-    import coverage
-
-    if coverage.Coverage.current():
-        if ApiUtil.get_env_var("PYTANGO_DISABLE_COVERAGE_TRACE_PATCHING"):
-            warnings.warn(
-                "Coverage run detected, but PYTANGO_DISABLE_COVERAGE_TRACE_PATCHING "
-                "environment variable is set. Reported coverage may be inaccurate.",
-                category=PyTangoUserWarning,
-            )
-        elif _debug_run_active:
-            warnings.warn(
-                "Coverage run detected, but debugger also detected. "
-                "Patching only for debugger, not for coverage."
-                "Reported coverage may be inaccurate.",
-                category=PyTangoUserWarning,
-            )
-        else:
-            if getattr(threading, "_trace_hook", None):
-                _coverage_run_active = True
-                warnings.warn(
-                    "Coverage run detected: tango.server.Device methods "
-                    "will be patched for tracing.",
-                    category=PyTangoUserWarning,
-                )
-            else:
-                warnings.warn(
-                    "Coverage run detected, but unable to get threading._trace_hook. "
-                    "Reported coverage may be inaccurate.",
-                    category=PyTangoUserWarning,
-                )
-
-except Exception:
-    pass
-
-
-_force_tracing = _debug_run_active or _coverage_run_active
-
-
-def _forcefully_traced_method(fn):
-    @functools.wraps(fn)
-    def trace_wrapper(*args, **kwargs):
-        original_tracer = "EMPTY"
-        if _debug_run_active:
-            pydevd.settrace(suspend=False, trace_only_current_thread=True)
-        elif _coverage_run_active:
-            original_tracer = sys.gettrace()
-            threading_trace_hook = getattr(threading, "_trace_hook", None)
-            if threading_trace_hook:
-                sys.settrace(threading_trace_hook)
-        try:
-            ret = fn(*args, **kwargs)
-        finally:
-            if original_tracer != "EMPTY":
-                sys.settrace(original_tracer)
-        return ret
-
-    return trace_wrapper
-
 
 def from_typeformat_to_type(dtype, dformat):
     if dformat == AttrDataFormat.SCALAR:
@@ -169,9 +95,6 @@ def __get_wrapped_read_method(attribute, read_method):
     if already_wrapped:
         return read_method
 
-    if _force_tracing:
-        read_method = _forcefully_traced_method(read_method)
-
     if attribute.read_green_mode:
 
         @functools.wraps(read_method)
@@ -191,6 +114,8 @@ def __get_wrapped_read_method(attribute, read_method):
                 set_complex_value(attr, ret)
             return ret
 
+    if _force_tracing:
+        read_attr = _forcefully_traced_method(read_attr)
     read_attr.__access_wrapped__ = True
     return read_attr
 
@@ -225,9 +150,6 @@ def __get_wrapped_write_method(attribute, write_method):
     if already_wrapped:
         return write_method
 
-    if _force_tracing:
-        write_method = _forcefully_traced_method(write_method)
-
     if attribute.write_green_mode:
 
         @functools.wraps(write_method)
@@ -242,6 +164,8 @@ def __get_wrapped_write_method(attribute, write_method):
             value = attr.get_write_value()
             return write_method(self, value)
 
+    if _force_tracing:
+        write_attr = _forcefully_traced_method(write_attr)
     write_attr.__access_wrapped__ = True
     return write_attr
 
@@ -281,9 +205,6 @@ def __get_wrapped_isallowed_method(attribute, isallowed_method):
     if already_wrapped:
         return isallowed_method
 
-    if _force_tracing:
-        isallowed_method = _forcefully_traced_method(isallowed_method)
-
     if attribute.isallowed_green_mode:
 
         @functools.wraps(isallowed_method)
@@ -294,6 +215,8 @@ def __get_wrapped_isallowed_method(attribute, isallowed_method):
     else:
         isallowed_attr = isallowed_method
 
+    if _force_tracing:
+        isallowed_attr = _forcefully_traced_method(isallowed_attr)
     if isallowed_attr is not isallowed_method:
         isallowed_attr.__access_wrapped__ = True
     return isallowed_attr
@@ -394,9 +317,6 @@ def __get_wrapped_pipe_read_method(pipe, read_method):
     if already_wrapped:
         return read_method
 
-    if _force_tracing:
-        read_method = _forcefully_traced_method(read_method)
-
     if pipe.read_green_mode:
 
         @functools.wraps(read_method)
@@ -416,8 +336,9 @@ def __get_wrapped_pipe_read_method(pipe, read_method):
                 pipe.set_value(ret)
             return ret
 
-    if read_pipe is not read_method:
-        read_pipe.__access_wrapped__ = True
+    if _force_tracing:
+        read_pipe = _forcefully_traced_method(read_pipe)
+    read_pipe.__access_wrapped__ = True
     return read_pipe
 
 
@@ -448,9 +369,6 @@ def __get_wrapped_pipe_write_method(pipe, write_method):
     if already_wrapped:
         return write_method
 
-    if _force_tracing:
-        write_method = _forcefully_traced_method(write_method)
-
     if pipe.write_green_mode:
 
         @functools.wraps(write_method)
@@ -465,6 +383,8 @@ def __get_wrapped_pipe_write_method(pipe, write_method):
             value = pipe.get_value()
             return write_method(self, value)
 
+    if _force_tracing:
+        write_pipe = _forcefully_traced_method(write_pipe)
     write_pipe.__access_wrapped__ = True
     return write_pipe
 
@@ -504,9 +424,6 @@ def __get_wrapped_pipe_isallowed_method(pipe, isallowed_method):
     if already_wrapped:
         return isallowed_method
 
-    if _force_tracing:
-        isallowed_method = _forcefully_traced_method(isallowed_method)
-
     if pipe.isallowed_green_mode:
 
         @functools.wraps(isallowed_method)
@@ -517,6 +434,8 @@ def __get_wrapped_pipe_isallowed_method(pipe, isallowed_method):
     else:
         isallowed_pipe = isallowed_method
 
+    if _force_tracing:
+        isallowed_pipe = _forcefully_traced_method(isallowed_pipe)
     if isallowed_pipe is not isallowed_method:
         isallowed_pipe.__access_wrapped__ = True
     return isallowed_pipe
@@ -571,7 +490,9 @@ def __get_property_type_from_hint(property, type_hint):
         property.dtype = from_typeformat_to_type(*get_tango_type_format(dtype))
 
 
-def __patch_is_command_allowed_method(tango_device_klass, is_allowed_method, cmd_name):
+def __patch_is_command_allowed_method(
+    tango_device_klass, is_allowed_method, cmd_name, green_mode
+):
     """
     :param tango_device_klass: a DeviceImpl class
     :type tango_device_klass: class
@@ -579,20 +500,25 @@ def __patch_is_command_allowed_method(tango_device_klass, is_allowed_method, cmd
     :type is_allowed_method: callable
     :param cmd_name: command name
     :type cmd_name: str
+    :param green_mode: indicates whether method should be wrapped with executor or not
+    :type green_mode: bool
     """
     already_wrapped = hasattr(is_allowed_method, "__access_wrapped__")
     if already_wrapped:
         return is_allowed_method.__wrapped_method_name__
 
-    if _force_tracing:
-        is_allowed_method = _forcefully_traced_method(is_allowed_method)
-
     method_name = getattr(is_allowed_method, "__name__", f"is_{cmd_name}_allowed")
     method_name = f"__wrapped_{method_name}__"
 
-    wrapped_method = run_in_executor(is_allowed_method)
-    wrapped_method.__access_wrapped__ = True
-    wrapped_method.__wrapped_method_name__ = method_name
+    if green_mode:
+        wrapped_method = run_in_executor(is_allowed_method)
+    else:
+        wrapped_method = is_allowed_method
+    if _force_tracing:
+        wrapped_method = _forcefully_traced_method(wrapped_method)
+    if wrapped_method is not is_allowed_method:
+        wrapped_method.__access_wrapped__ = True
+        wrapped_method.__wrapped_method_name__ = method_name
     setattr(tango_device_klass, method_name, wrapped_method)
 
     return method_name
@@ -605,7 +531,7 @@ def __unwrap_method(method):
     return method
 
 
-def __warn_if_any_standard_device_method_should_be_coroutine(klass):
+def __warn_if_standard_device_methods_should_be_coroutine(klass):
     worker = get_worker()
     # get base device class:
     if isinstance(worker, AsyncioExecutor):
@@ -621,113 +547,197 @@ def __warn_if_any_standard_device_method_should_be_coroutine(klass):
                 ):
                     user_method = __unwrap_method(getattr(klass, method))
                     base_method = __unwrap_method(getattr(parent, method))
-                    if user_method != base_method and not asyncio.iscoroutinefunction(
+                    if user_method != base_method and not _is_coroutine_function(
                         user_method
                     ):
                         warnings.warn(
-                            f"Note: {method} function in Asyncio device should be coroutine!",
-                            category=PyTangoUserWarning,
+                            f"{method} is sync: support of "
+                            f"sync functions in Asyncio Servers is "
+                            f"deprecated. Use 'async def' instead of 'def'.",
+                            DeprecationWarning,
                         )
 
 
+async def __async_method_helper(method, *args, **kwargs):
+    return await get_worker().delegate(method, *args, **kwargs)
+
+
 def __patch_standard_device_methods(klass):
     # TODO allow to force non green mode
 
+    # init_device
     init_device_orig = klass.init_device
     already_wrapped = hasattr(init_device_orig, "__access_wrapped__")
     if not already_wrapped:
-        if _force_tracing:
-            init_device_orig = _forcefully_traced_method(init_device_orig)
+        is_base_klass_init_device = init_device_orig == BaseDevice.init_device
 
         @functools.wraps(init_device_orig)
         def init_device(self):
-            __warn_if_any_standard_device_method_should_be_coroutine(klass)
-            return get_worker().execute(init_device_orig, self)
+            __warn_if_standard_device_methods_should_be_coroutine(klass)
+            worker = get_worker()
+            if isinstance(worker, AsyncioExecutor) and is_base_klass_init_device:
+                # if coroutine will never be awaited, we want that RuntimeWarning will print us
+                # 'init_device' instead of "__async_method_helper", so we create another intermediate
+                # layer with proper  __qualname__
+                method_helper = __async_method_helper
+                method_helper.__qualname__ = "BaseDevice.init_device"
+                return worker.execute(method_helper, init_device_orig, self)
+            else:
+                return worker.execute(init_device_orig, self)
 
+        if _force_tracing:
+            init_device = _forcefully_traced_method(
+                init_device, is_kernel_method=is_base_klass_init_device
+            )
         init_device.__access_wrapped__ = True
         setattr(klass, "init_device", init_device)
 
+    # delete_device
     delete_device_orig = klass.delete_device
     already_wrapped = hasattr(delete_device_orig, "__access_wrapped__")
     if not already_wrapped:
-        if _force_tracing:
-            delete_device_orig = _forcefully_traced_method(delete_device_orig)
+        is_base_klass_delete_device = delete_device_orig == BaseDevice.delete_device
 
         @functools.wraps(delete_device_orig)
         def delete_device(self):
-            return get_worker().execute(delete_device_orig, self)
+            worker = get_worker()
+            if isinstance(worker, AsyncioExecutor) and is_base_klass_delete_device:
+                method_helper = __async_method_helper
+                method_helper.__qualname__ = "BaseDevice.delete_device"
+                return worker.execute(method_helper, delete_device_orig, self)
+            else:
+                return worker.execute(delete_device_orig, self)
 
+        if _force_tracing:
+            delete_device = _forcefully_traced_method(
+                delete_device, is_kernel_method=is_base_klass_delete_device
+            )
         delete_device.__access_wrapped__ = True
         setattr(klass, "delete_device", delete_device)
 
     dev_state_orig = klass.dev_state
     already_wrapped = hasattr(dev_state_orig, "__access_wrapped__")
     if not already_wrapped:
-        dev_state_async = klass._BaseDevice__asyncio_dev_state
-        is_base_klass_state = dev_state_orig == BaseDevice.dev_state
-        if _force_tracing:
-            dev_state_orig = _forcefully_traced_method(dev_state_orig)
-            dev_state_async = _forcefully_traced_method(dev_state_async)
+        is_base_klass_dev_state = dev_state_orig == BaseDevice.dev_state
 
         @functools.wraps(dev_state_orig)
         def dev_state(self):
-            if isinstance(get_worker(), AsyncioExecutor) and is_base_klass_state:
-                return get_worker().execute(dev_state_async, self)
+            worker = get_worker()
+            if isinstance(worker, AsyncioExecutor) and is_base_klass_dev_state:
+                method_helper = __async_method_helper
+                method_helper.__qualname__ = "BaseDevice.dev_state"
+                return worker.execute(method_helper, dev_state_orig, self)
             else:
-                return get_worker().execute(dev_state_orig, self)
+                return worker.execute(dev_state_orig, self)
 
+        if _force_tracing:
+            dev_state = _forcefully_traced_method(
+                dev_state, is_kernel_method=is_base_klass_dev_state
+            )
         dev_state.__access_wrapped__ = True
         setattr(klass, "dev_state", dev_state)
 
+    # device_status
     dev_status_orig = klass.dev_status
     already_wrapped = hasattr(dev_status_orig, "__access_wrapped__")
     if not already_wrapped:
-        if _force_tracing:
-            dev_status_orig = _forcefully_traced_method(dev_status_orig)
+        is_base_klass_dev_status = dev_status_orig == BaseDevice.dev_status
 
         @functools.wraps(dev_status_orig)
         def dev_status(self):
-            return get_worker().execute(dev_status_orig, self)
+            worker = get_worker()
+            if isinstance(worker, AsyncioExecutor) and is_base_klass_dev_status:
+                method_helper = __async_method_helper
+                method_helper.__qualname__ = "BaseDevice.dev_status"
+                return worker.execute(method_helper, dev_status_orig, self)
+            else:
+                return worker.execute(dev_status_orig, self)
 
+        if _force_tracing:
+            dev_status = _forcefully_traced_method(
+                dev_status, is_kernel_method=is_base_klass_dev_status
+            )
         dev_status.__access_wrapped__ = True
         setattr(klass, "dev_status", dev_status)
 
+    # read_attr_hardware
     read_attr_hardware_orig = klass.read_attr_hardware
     already_wrapped = hasattr(read_attr_hardware_orig, "__access_wrapped__")
     if not already_wrapped:
-        if _force_tracing:
-            read_attr_hardware_orig = _forcefully_traced_method(read_attr_hardware_orig)
+        is_base_klass_read_attr_hardware = (
+            read_attr_hardware_orig == BaseDevice.read_attr_hardware
+        )
 
         @functools.wraps(read_attr_hardware_orig)
         def read_attr_hardware(self, attr_list):
-            return get_worker().execute(read_attr_hardware_orig, self, attr_list)
+            worker = get_worker()
+            if isinstance(worker, AsyncioExecutor) and is_base_klass_read_attr_hardware:
+                method_helper = __async_method_helper
+                method_helper.__qualname__ = "BaseDevice.read_attr_hardware"
+                return worker.execute(
+                    method_helper, read_attr_hardware_orig, self, attr_list
+                )
+            else:
+                return worker.execute(read_attr_hardware_orig, self, attr_list)
 
+        if _force_tracing:
+            read_attr_hardware = _forcefully_traced_method(
+                read_attr_hardware, is_kernel_method=is_base_klass_read_attr_hardware
+            )
         read_attr_hardware.__access_wrapped__ = True
         setattr(klass, "read_attr_hardware", read_attr_hardware)
 
+    # always_executed_hook
     always_executed_hook_orig = klass.always_executed_hook
     already_wrapped = hasattr(always_executed_hook_orig, "__access_wrapped__")
     if not already_wrapped:
-        if _force_tracing:
-            always_executed_hook_orig = _forcefully_traced_method(
-                always_executed_hook_orig
-            )
+        is_base_klass_always_executed_hook = (
+            always_executed_hook_orig == BaseDevice.always_executed_hook
+        )
 
         @functools.wraps(always_executed_hook_orig)
         def always_executed_hook(self):
-            return get_worker().execute(always_executed_hook_orig, self)
+            worker = get_worker()
+            if (
+                isinstance(worker, AsyncioExecutor)
+                and is_base_klass_always_executed_hook
+            ):
+                method_helper = __async_method_helper
+                method_helper.__qualname__ = "BaseDevice.always_executed_hook"
+                return worker.execute(method_helper, always_executed_hook_orig, self)
+            else:
+                return worker.execute(always_executed_hook_orig, self)
 
+        if _force_tracing:
+            always_executed_hook = _forcefully_traced_method(
+                always_executed_hook,
+                is_kernel_method=is_base_klass_always_executed_hook,
+            )
         always_executed_hook.__access_wrapped__ = True
         setattr(klass, "always_executed_hook", always_executed_hook)
 
+    # server_init_hook
     server_init_hook_orig = klass.server_init_hook
     already_wrapped = hasattr(server_init_hook_orig, "__access_wrapped__")
     if not already_wrapped:
+        is_base_klass_server_init_hook = (
+            server_init_hook_orig == BaseDevice.server_init_hook
+        )
 
         @functools.wraps(server_init_hook_orig)
         def server_init_hook(self):
-            return get_worker().execute(server_init_hook_orig, self)
+            worker = get_worker()
+            if isinstance(worker, AsyncioExecutor) and is_base_klass_server_init_hook:
+                method_helper = __async_method_helper
+                method_helper.__qualname__ = "BaseDevice.server_init_hook"
+                return worker.execute(method_helper, server_init_hook_orig, self)
+            else:
+                return worker.execute(server_init_hook_orig, self)
 
+        if _force_tracing:
+            server_init_hook = _forcefully_traced_method(
+                server_init_hook, is_kernel_method=is_base_klass_server_init_hook
+            )
         server_init_hook.__access_wrapped__ = True
         setattr(klass, "server_init_hook", server_init_hook)
 
@@ -739,7 +749,11 @@ class _DeviceClass(DeviceClass):
 
         if _force_tracing:
             orig_dyn_attr = getattr(self, "dyn_attr")
-            setattr(self, "dyn_attr", _forcefully_traced_method(orig_dyn_attr))
+            setattr(
+                self,
+                "dyn_attr",
+                _forcefully_traced_method(orig_dyn_attr, is_kernel_method=True),
+            )
 
     def dyn_attr(self, dev_list):
         """Invoked to create dynamic attributes for the given devices.
@@ -837,6 +851,7 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
                     is_allowed_method = cmd_info[2]["Is allowed"]
                 else:
                     is_allowed_method = f"is_{cmd_name}_allowed"
+                is_allowed_method_green_mode = cmd_info[2]["Is allowed green_mode"]
 
                 if is_pure_str(is_allowed_method):
                     is_allowed_method = getattr(
@@ -845,7 +860,10 @@ def __create_tango_deviceclass_klass(tango_device_klass, attrs=None):
 
                 if is_allowed_method is not None:
                     cmd_info[2]["Is allowed"] = __patch_is_command_allowed_method(
-                        tango_device_klass, is_allowed_method, cmd_name
+                        tango_device_klass,
+                        is_allowed_method,
+                        cmd_name,
+                        is_allowed_method_green_mode,
                     )
 
     __patch_standard_device_methods(tango_device_klass)
@@ -882,7 +900,7 @@ def is_tango_object(arg):
     """Return tango data if the argument is a tango object,
     False otherwise.
     """
-    classes = attribute, device_property, pipe
+    classes = attribute, device_property, class_property, pipe
     if isinstance(arg, classes):
         return arg
     try:
@@ -939,9 +957,44 @@ class BaseDevice(LatestDeviceImpl):
     instance of MetaDevice. Use tango.server.Device instead.
     """
 
+    DEVICE_CLASS_DESCRIPTION: ClassVar[Union[str, None]] = None
+    """Description of the device class (optional).
+
+    If not specified, the class docstring is used.
+    Available to clients via :meth:`tango.DeviceProxy.description`.
+    Use as a class variable.
+
+    :meta hide-value:
+    """
+
+    DEVICE_CLASS_INITIAL_STATUS: ClassVar[str] = StatusNotSet
+    """Initial status string for all instances of the device (optional).
+
+    Use as a class variable.
+
+    :meta hide-value:
+    """
+
+    DEVICE_CLASS_INITIAL_STATE: ClassVar[DevState] = DevState.UNKNOWN
+    """Initial state value for all instances of the device (optional).
+
+    Use as a class variable.
+
+    :meta hide-value:
+    """
+
     def __init__(self, cl, name):
         self._tango_properties = {}
-        LatestDeviceImpl.__init__(self, cl, name)
+        if self.DEVICE_CLASS_DESCRIPTION is not None:
+            dev_desc = self.DEVICE_CLASS_DESCRIPTION
+        elif self.__doc__:
+            dev_desc = self.__doc__
+        else:
+            dev_desc = "A TANGO device"
+        dev_state = self.DEVICE_CLASS_INITIAL_STATE
+        dev_status = self.DEVICE_CLASS_INITIAL_STATUS
+        LatestDeviceImpl.__init__(self, cl, name, dev_desc, dev_state, dev_status)
+        self._configure_device_telemetry(cl.get_name(), name)
         self.init_device()
 
     def init_device(self):
@@ -958,17 +1011,6 @@ class BaseDevice(LatestDeviceImpl):
     def read_attr_hardware(self, attr_list):
         return LatestDeviceImpl.read_attr_hardware(self, attr_list)
 
-    async def __asyncio_dev_state(self):
-        if sys.version_info >= (3, 9):
-            return await asyncio.to_thread(LatestDeviceImpl.dev_state, self)
-        else:
-            warnings.warn(
-                "DevState.ALARM cannot be correctly reported with GreenMode.Asyncio prior to Python 3.9",
-                category=PyTangoUserWarning,
-            )
-            # See https://gitlab.com/tango-controls/pytango/-/merge_requests/564 for details
-            return LatestDeviceImpl.dev_state(self)
-
     def dev_state(self):
         return LatestDeviceImpl.dev_state(self)
 
@@ -1026,6 +1068,12 @@ class BaseDevice(LatestDeviceImpl):
         Method executed at initializion phase to create dynamic
         attributes. Default implementation does nothing. Overwrite
         when necessary.
+
+        .. note::
+            This method is only called once when the device server starts,
+            after init_device(), but before the device is marked as exported.
+            If the Init command is executed on the device, the
+            initialize_dynamic_attributes() method will not be called again.
         """
         pass
 
@@ -1051,6 +1099,43 @@ class BaseDevice(LatestDeviceImpl):
         kwargs.setdefault("green_mode", green_mode)
         return run((cls,), args, **kwargs)
 
+    def _configure_device_telemetry(self, class_name, device_name):
+        device_tracer_provider = self.create_telemetry_tracer_provider(
+            class_name, device_name
+        )
+        device_tracer = self.create_telemetry_tracer(device_tracer_provider)
+        self._tango_telemetry_tracer = device_tracer
+
+    def create_telemetry_tracer_provider(
+        self, class_name, device_name
+    ) -> "opentelemetry.trace.TracerProvider":  # noqa: F821
+        """Factory method returning a TracerProvider for telemetry.
+
+        The default implementation can be overridden.
+
+        .. versionadded:: 10.0.0
+        """
+        tracer_provider_factory = get_telemetry_tracer_provider_factory()
+        return tracer_provider_factory(class_name, device_name)
+
+    def create_telemetry_tracer(
+        self, device_tracer_provider
+    ) -> "opentelemetry.trace.Tracer":  # noqa: F821
+        """Factory method returning a Tracer for telemetry.
+
+        The default implementation can be overridden.
+
+        .. versionadded:: 10.0.0
+        """
+        return _create_device_telemetry_tracer(device_tracer_provider)
+
+    def get_telemetry_tracer(self) -> "opentelemetry.trace.Tracer":  # noqa: F821
+        """Returns device telemetry tracer, or None if telemetry disabled.
+
+        .. versionadded:: 10.0.0
+        """
+        return self._tango_telemetry_tracer
+
 
 class attribute(AttrData):
     '''
@@ -1506,8 +1591,10 @@ def command(
     doc_out="",
     display_level=None,
     polling_period=None,
-    green_mode=None,
+    green_mode=True,
     fisallowed=None,
+    cmd_green_mode=None,
+    isallowed_green_mode=None,
 ):
     """
     Declares a new tango command in a :class:`Device`.
@@ -1543,29 +1630,44 @@ def command(
     :param dtype_in:
         a :ref:`data type <pytango-hlapi-datatypes>` describing the
         type of parameter. Default is None meaning no parameter.
+
     :param dformat_in: parameter data format. Default is None.
     :type dformat_in: AttrDataFormat
+
     :param doc_in: parameter documentation
     :type doc_in: str
 
     :param dtype_out:
         a :ref:`data type <pytango-hlapi-datatypes>` describing the
         type of return value. Default is None meaning no return value.
+
     :param dformat_out: return value data format. Default is None.
     :type dformat_out: AttrDataFormat
+
     :param doc_out: return value documentation
     :type doc_out: str
+
     :param display_level: display level for the command (optional)
     :type display_level: DispLevel
+
     :param polling_period: polling period in milliseconds (optional)
     :type polling_period: int
-    :param green_mode:
-        set green mode on this specific command. Default value is None meaning
-        use the server green mode. Set it to GreenMode.Synchronous to force
-        a non green command in a green server.
+
+    :param green_mode: DEPRECATED: green mode for command method. If True: run with green mode executor, if False: run directly.
+        See the green_mode parameter deprecation note below for more details.
+    :type green_mode: bool
+
     :param fisallowed: is allowed method for command
     :type fisallowed: str or callable
 
+    :param cmd_green_mode: green mode for command method. If True: run with green mode executor, if False: run directly
+        See the green_mode parameter deprecation note below for more details.
+    :type cmd_green_mode: bool
+
+    :param isallowed_green_mode: green mode for isallowed method. If True: run with green mode executor, if False: run directly
+        See the green_mode parameter deprecation note below for more details.
+    :type isallowed_green_mode: bool
+
     .. versionadded:: 8.1.7
         added green_mode option
 
@@ -1574,6 +1676,22 @@ def command(
 
     .. versionadded:: 9.4.0
         added fisallowed option
+
+     .. versionadded:: 10.0.0
+         added cmd_green_mode and isallowed_green_mode options
+
+    .. versionchanged:: 10.0.0
+        the way that the green_mode parameter is interpreted was changed to be consistent with the same parameter for attributes.
+        Now it expects bool, which indicates, if methods should be run with executor (green_mode=True, default) or bypass it (green_mode=False)
+        Before it was either green_mode=None - use executor or green_mode=GreenMode.Synchronous - bypass it.
+        However, due python by default casts GreenMode.Synchronous (which is int value 0) to False bool,
+        old code is automatically backward compatible.
+
+    .. deprecated:: 10.0.0
+         green_mode parameter is deprecated and may be removed in future.  Use cmd_green_mode and isallowed_green_mode parameters instead.
+         The new parameters match how attributes and pipes are defined, offer more flexibility, and are clearer.
+         If you use both old green_mode, and new isallowed_green_mode and cmd_green_mode - the new ones take priority.
+
     """
     if f is None:
         return functools.partial(
@@ -1588,6 +1706,8 @@ def command(
             polling_period=polling_period,
             green_mode=green_mode,
             fisallowed=fisallowed,
+            cmd_green_mode=cmd_green_mode,
+            isallowed_green_mode=isallowed_green_mode,
         )
     name = f.__name__
 
@@ -1619,30 +1739,45 @@ def command(
         config_dict["Polling period"] = polling_period
     if fisallowed is not None:
         config_dict["Is allowed"] = fisallowed
+    config_dict["Is allowed green_mode"] = (
+        isallowed_green_mode if isallowed_green_mode is not None else green_mode
+    )
 
-    if green_mode == GreenMode.Synchronous:
-        cmd = f
-    else:
-
-        @functools.wraps(f)
-        def cmd(self, *args, **kwargs):
-            return get_worker().execute(f, self, *args, **kwargs)
-
-    if _force_tracing:
-        cmd = _forcefully_traced_method(cmd)
-
-    cmd.__tango_command__ = name, [din, dout, config_dict]
+    cmd_green_mode = cmd_green_mode if cmd_green_mode is not None else green_mode
+    command_method = __get_wrapped_command_method(f, cmd_green_mode)
+    command_method.__tango_command__ = name, [din, dout, config_dict]
 
     # try to create a minimalistic __doc__
-    if cmd.__doc__ is None:
+    if command_method.__doc__ is None:
         try:
-            cmd.__doc__ = __build_command_doc(
+            command_method.__doc__ = __build_command_doc(
                 f, name, dtype_in, doc_in, dtype_out, doc_out
             )
         except Exception:
-            cmd.__doc__ = "TANGO command"
+            command_method.__doc__ = "TANGO command"
 
-    return cmd
+    return command_method
+
+
+def __get_wrapped_command_method(cmd_method, cmd_green_mode):
+    already_wrapped = hasattr(cmd_method, "__access_wrapped__")
+    if already_wrapped:
+        return cmd_method
+
+    if cmd_green_mode:
+
+        @functools.wraps(cmd_method)
+        def wrapped_command_method(self, *args, **kwargs):
+            return get_worker().execute(cmd_method, self, *args, **kwargs)
+
+    else:
+        wrapped_command_method = cmd_method
+
+    if _force_tracing:
+        wrapped_command_method = _forcefully_traced_method(wrapped_command_method)
+    if wrapped_command_method is not cmd_method:
+        wrapped_command_method.__access_wrapped__ = True
+    return wrapped_command_method
 
 
 class _BaseProperty:
@@ -1742,7 +1877,7 @@ class class_property(_BaseProperty):
     pass
 
 
-def __to_cb(callback, cb_type):
+def __to_callback(callback, cb_type, green_mode):
     if callback is None:
         return lambda: None
 
@@ -1755,19 +1890,27 @@ def __to_cb(callback, cb_type):
         length = len(callback)
         if length < 1 or length > 3:
             raise TypeError(err_msg)
-        cb = callback[0]
-        if not callable(cb):
+        callback = callback[0]
+        if not callable(callback):
             raise TypeError(err_msg)
         args, kwargs = [], {}
         if length > 1:
             args = callback[1]
         if length > 2:
             kwargs = callback[2]
-        f = functools.partial(cb, *args, **kwargs)
+        f = functools.partial(callback, *args, **kwargs)
     else:
         raise TypeError(err_msg)
 
-    return f
+    if green_mode == GreenMode.Asyncio and not _is_coroutine_function(f):
+
+        @functools.wraps(f)
+        async def async_callback():
+            return f()
+
+        return async_callback
+    else:
+        return f
 
 
 def _to_classes(classes):
@@ -1858,8 +2001,12 @@ def __server_run(
     if args is None:
         args = sys.argv
 
-    pre_init_callback = __to_cb(pre_init_callback, "pre_init_callback")
-    post_init_callback = __to_cb(post_init_callback, "post_init_callback")
+    pre_init_callback = __to_callback(
+        pre_init_callback, "pre_init_callback", green_mode
+    )
+    post_init_callback = __to_callback(
+        post_init_callback, "post_init_callback", green_mode
+    )
 
     if util is None:
         util = Util.init(args)
@@ -1901,6 +2048,7 @@ def run(
     post_init_callback=None,
     green_mode=None,
     raises=False,
+    err_stream=sys.stderr,
 ):
     """
     Provides a simple way to run a tango server. It handles exceptions
@@ -2007,6 +2155,9 @@ def run(
         Disable error handling and propagate exceptions from the server
     :type raises: bool
 
+    :param err_stream:
+        stream where to put catched exceptions [default: sys.stderr]
+
     :return: The Util singleton object
     :rtype: :class:`~tango.Util`
 
@@ -2021,6 +2172,9 @@ def run(
 
     .. versionchanged:: 9.5.0
         `pre_init_callback` argument has been added
+
+    .. versionchanged:: 10.0.0
+        `err_stream` argument has been added
     """
     server_run = functools.partial(
         __server_run,
@@ -2037,7 +2191,7 @@ def run(
     if raises:
         return server_run()
     # Run the server with error handling
-    write = msg_stream.write if msg_stream else lambda msg: None
+    write = err_stream.write if err_stream else lambda msg: None
     try:
         return server_run()
     except KeyboardInterrupt:
@@ -2063,6 +2217,7 @@ def server_run(
     pre_init_callback=None,
     post_init_callback=None,
     green_mode=None,
+    err_stream=sys.stderr,
 ):
     """
     Since PyTango 8.1.2 it is just an alias to
@@ -2089,6 +2244,9 @@ def server_run(
     .. versionchanged:: 9.5.0
         `pre_init_callback` argument has been added
 
+    .. versionchanged:: 10.0.0
+        `err_stream` argument has been added
+
     """
     return run(
         classes,
@@ -2100,6 +2258,7 @@ def server_run(
         pre_init_callback=pre_init_callback,
         post_init_callback=post_init_callback,
         green_mode=green_mode,
+        err_stream=sys.stderr,
     )
 
 
