@@ -135,8 +135,11 @@ def get_server_port_via_pid(pid, host, retries=400, delay=0.03):
 
 def _get_listening_tcp_ports(pid):
     p = psutil.Process(pid)
-    conns = p.connections(kind="tcp")
-    return list(set([c.laddr[1] for c in conns]))
+    if hasattr(p, "net_connections"):
+        conns = p.net_connections(kind="tcp")
+    else:
+        conns = p.connections(kind="tcp")  # deprecated in psutil v6.0.0
+    return list(set([c.laddr.port for c in conns if c.status == "LISTEN"]))
 
 
 def _get_giop_port(host, ports):
@@ -618,15 +621,15 @@ class MultiDeviceTestContext:
             os.close(self.handle)
             os.unlink(self.db)
 
-    def get_server_access(self):
+    def get_server_access(self) -> str:
         """Return the full server name."""
         return f"tango://{self.host}:{self.port}/{self.server_name}#{NO_DB_FRAGMENT}"
 
-    def get_device_access(self, device_name):
+    def get_device_access(self, device_name) -> str:
         """Return the full device name."""
         return f"tango://{self.host}:{self.port}/{device_name}#{NO_DB_FRAGMENT}"
 
-    def get_device(self, device_name):
+    def get_device(self, device_name) -> DeviceProxy:
         """Return the device proxy corresponding to the given device name.
 
         Maintains previously accessed device proxies in a cache to not recreate
@@ -717,7 +720,7 @@ class MultiDeviceTestContext:
             else:
                 os.environ.pop(key)  # unset environment var
 
-    def __enter__(self):
+    def __enter__(self) -> "MultiDeviceTestContext":
         """Enter method for context support.
 
         :return:
@@ -856,7 +859,7 @@ class DeviceTestContext(MultiDeviceTestContext):
         self.device_name = device_name
         self.device = self.server = None
 
-    def get_device_access(self, device_name=None):
+    def get_device_access(self, device_name=None) -> str:
         """Return the full device name."""
         if device_name is None:
             device_name = self.device_name
@@ -868,7 +871,7 @@ class DeviceTestContext(MultiDeviceTestContext):
         self.device = self.get_device(self.device_name)
         self.device.ping()
 
-    def __enter__(self):
+    def __enter__(self) -> DeviceProxy:
         """Enter method for context support.
 
         :return:
