@@ -5,13 +5,24 @@ import numpy as np
 
 try:
     import numpy.typing as npt
-except ImportError:
+
+    # in numpy 1.20 npt does not have npt.NDArray, so we cannot parce hits
+    npt.NDArray
+except (AttributeError, ImportError):
     npt = None
 
 from functools import wraps
 
 # Local imports
-from tango import DevState, GreenMode, AttrDataFormat, ExtractAs, DevFailed
+from tango import (
+    DevState,
+    GreenMode,
+    AttrDataFormat,
+    ExtractAs,
+    DevFailed,
+    DevVarLongStringArray,
+    DevVarDoubleStringArray,
+)
 from tango.server import Device
 from tango.test_context import MultiDeviceTestContext, DeviceTestContext
 from tango.utils import is_non_str_seq, FROM_TANGO_TO_NUMPY_TYPE
@@ -38,6 +49,7 @@ __all__ = [
     "convert_dtype_to_typing_hint",
     "assert_close",
     "general_decorator",
+    "general_asyncio_decorator",
     "DEVICE_SERVER_ARGUMENTS",
 ]
 
@@ -155,6 +167,11 @@ GENERAL_TYPED_VALUES = {
     ),
 }
 
+COMMAND_TYPED_VALUES = {
+    DevVarLongStringArray: ([[1, 2, 3], ["foo", "bar", "hmm"]],),
+    DevVarDoubleStringArray: ([[1.1, 2.2, 3.3], ["foo", "bar", "hmm"]],),
+}
+
 IMAGE_TYPED_VALUES = {
     ((int,),): (
         np.vstack((np.array([1, 2]), np.array([3, 4]))),
@@ -368,6 +385,12 @@ def convert_dtype_to_typing_hint(dtype):
         else:
             tuple_hint = tuple[dtype, dtype, dtype]
             list_hint = list[dtype]
+    elif dtype == DevVarLongStringArray:
+        tuple_hint = tuple[tuple[int], tuple[str]]
+        list_hint = list[list[int], list[str]]
+    elif dtype == DevVarDoubleStringArray:
+        tuple_hint = tuple[tuple[float], tuple[str]]
+        list_hint = list[list[float], list[str]]
     else:
         tuple_hint = dtype
         list_hint = dtype
@@ -387,9 +410,25 @@ def general_decorator(function=None):
         return general_decorator
 
 
+def general_asyncio_decorator(function=None):
+    if function:
+
+        @wraps(function)
+        async def _wrapper(*args, **kwargs):
+            return await function(*args, **kwargs)
+
+        return _wrapper
+    else:
+        return general_asyncio_decorator
+
+
 def repr_type(x):
     if isinstance(x, (list, tuple)):
         return f"({repr_type(x[0])},)"
+    elif x == DevVarLongStringArray:
+        return "DevVarLongStringArray"
+    elif x == DevVarDoubleStringArray:
+        return "DevVarDoubleStringArray"
     return f"{x.__name__}"
 
 
@@ -448,7 +487,11 @@ if pytest:
         if isinstance(a, str):
             assert a == b
             return
-
+        elif isinstance(a, dict):
+            for k, v in a.items():
+                assert k in b
+                assert_close(v, b[k])
+            return
         try:
             assert a == pytest.approx(b)
         except (ValueError, TypeError):
@@ -471,6 +514,10 @@ if pytest:
         if isinstance(dtype, (list, tuple)):
             dtype = dtype[0]
             return [create_result(dtype, v) for v in value]
+        elif dtype == DevVarLongStringArray:
+            return [create_result(dtype, v) for v, dtype in zip(value, [int, str])]
+        elif dtype == DevVarDoubleStringArray:
+            return [create_result(dtype, v) for v, dtype in zip(value, [float, str])]
 
         return __convert_value(value)
 
@@ -496,6 +543,15 @@ if pytest:
     @pytest.fixture(
         params=list(GENERAL_TYPED_VALUES.items()), ids=lambda x: repr_type(x[0])
     )
+    def general_typed_values(request):
+        dtype, values = request.param
+        expected = lambda v: create_result(dtype, v)
+        return dtype, values, expected
+
+    @pytest.fixture(
+        params=list({**GENERAL_TYPED_VALUES, **COMMAND_TYPED_VALUES}.items()),
+        ids=lambda x: repr_type(x[0]),
+    )
     def command_typed_values(request):
         dtype, values = request.param
         expected = lambda v: create_result(dtype, v)
