@@ -15,17 +15,26 @@ This is an internal PyTango module.
 
 
 import collections.abc
+import contextlib
 import os
+import re
+import socket
 import sys
 import types
 import numbers
 import inspect
 import enum
+import threading
+import warnings
+import functools
+import weakref
 
 import typing
 import numpy as np
 
 from argparse import HelpFormatter
+from collections import namedtuple
+from contextvars import ContextVar
 from urllib.parse import urlparse, urlunparse
 
 from packaging.version import Version
@@ -45,15 +54,22 @@ from tango._tango import (
     DataReadyEventData,
     DevFailed,
     DevState,
-    CommunicationFailed,
     PipeEventData,
     DevIntrChangeEventData,
     Database,
     EncodedAttribute,
+    ApiUtil,
+    EnsureOmniThread,
 )
 
 from tango import _tango
-from tango.constants import AlrmValueNotSpec, StatusNotSet, TgLibVers
+from tango._tango import _telemetry
+from tango.constants import (
+    AlrmValueNotSpec,
+    StatusNotSet,
+    TgLibVers,
+    TELEMETRY_SUPPORTED,
+)
 from tango.release import Release
 
 __all__ = (
@@ -81,6 +97,7 @@ __all__ = (
     "CaselessList",
     "CaselessDict",
     "EventCallback",
+    "AsyncEventCallback",
     "get_home",
     "from_version_str_to_hex_str",
     "from_version_str_to_int",
@@ -96,6 +113,15 @@ __all__ = (
     "InvalidTangoHostTrlError",
     "PyTangoUserWarning",
     "parse_type_hint",
+    "PyTangoThreadPoolExecutor",
+    "set_telemetry_tracer_provider_factory",
+    "get_telemetry_tracer_provider_factory",
+    "_create_device_telemetry_tracer",
+    "_get_non_tango_source_location",
+    "_span_to_cpptango",
+    "_telemetry_active",
+    "_trace_client",
+    "_DummyTracer",
 )
 
 __docformat__ = "restructuredtext"
@@ -443,6 +469,8 @@ def __get_tango_type(obj):
         r = CmdArgType.DevLong64
     elif isinstance(obj, __number_klasses):
         r = CmdArgType.DevDouble
+    else:
+        raise TypeError(f"Unsupported type {type(obj)}")
     return r, AttrDataFormat.SCALAR
 
 
@@ -551,6 +579,18 @@ def parse_type_hint(annotation, caller):
             and typing.get_args(dtype)[1] in [bytes, bytearray]
         ):
             return "DevEncoded", dformat, max_x, max_y
+        if (
+            n_elements in [2, 4]
+            and typing.get_args(dtype)[0] in [tuple[int], list[int]]
+            and typing.get_args(dtype)[1] in [tuple[str], list[str]]
+        ):
+            return "DevVarLongStringArray", dformat, max_x, max_y
+        if (
+            n_elements in [2, 4]
+            and typing.get_args(dtype)[0] in [tuple[float], list[float]]
+            and typing.get_args(dtype)[1] in [tuple[str], list[str]]
+        ):
+            return "DevVarDoubleStringArray", dformat, max_x, max_y
         if (
             n_elements == 3
             and typing.get_args(dtype)[1] == float
@@ -1602,101 +1642,6 @@ class CaselessDict(dict):
         return CaselessList(dict.keys(self))
 
 
-__DEFAULT_FACT_IOR_FILE = "/tmp/rdifact.ior"
-__BASE_LINE = "notifd"
-__END_NOTIFD_LINE = "/DEVICE/notifd:"
-__NOTIFD_FACTORY_PREFIX = "notifd/factory/"
-
-
-def notifd2db(
-    notifd_ior_file=__DEFAULT_FACT_IOR_FILE, files=None, host=None, out=sys.stdout
-):
-    ior_string = ""
-    with open(notifd_ior_file) as ior_file:
-        ior_string = ior_file.read()
-
-    if files is None:
-        return _notifd2db_real_db(ior_string, host=host, out=out)
-    else:
-        return _notifd2db_file_db(ior_string, files, out=out)
-
-
-def _notifd2db_file_db(ior_string, files, out=sys.stdout):
-    raise RuntimeError("Not implemented yet")
-
-    print(
-        "going to export notification service event factory to "
-        "device server property file(s) ...",
-        file=out,
-    )
-    for f in files:
-        with open(f, "w"):
-            pass
-    return
-
-
-def _notifd2db_real_db(ior_string, host=None, out=sys.stdout):
-    from tango import Database
-
-    print(
-        "going to export notification service event factory to Tango database ...",
-        file=out,
-    )
-
-    num_retries = 3
-    while num_retries > 0:
-        try:
-            db = Database()
-            db.set_timeout_millis(10000)
-            num_retries = 0
-        except DevFailed as df:
-            num_retries -= 1
-            if num_retries == 0:
-                print("Can't create Tango database object", file=out)
-                print(str(df), file=out)
-                return
-            print("Can't create Tango database object, retrying....", file=out)
-
-    if host is None:
-        import socket
-
-        host_name = socket.getfqdn()
-
-    global __NOTIFD_FACTORY_PREFIX
-    notifd_factory_name = __NOTIFD_FACTORY_PREFIX + host_name
-
-    args = notifd_factory_name, ior_string, host_name, str(os.getpid()), "1"
-
-    num_retries = 3
-    while num_retries > 0:
-        try:
-            db.command_inout("DbExportEvent", args)
-            print(
-                "Successfully exported notification service event factory for host",
-                host_name,
-                "to Tango database !",
-                file=out,
-            )
-            break
-        except CommunicationFailed as cf:
-            if len(cf.errors) >= 2:
-                if cf.errors[1].reason == "API_DeviceTimedOut":
-                    if num_retries > 0:
-                        num_retries -= 1
-                else:
-                    num_retries = 0
-            else:
-                num_retries = 0
-        except Exception:
-            num_retries = 0
-
-    if num_retries == 0:
-        print(
-            "Failed to export notification service event factory to TANGO database",
-            file=out,
-        )
-
-
 class EventCallback:
     """
     Useful event callback for test purposes
@@ -1821,6 +1766,15 @@ class EventCallback:
             return
 
 
+class AsyncEventCallback(EventCallback):
+    async def push_event(self, evt):
+        """Internal usage only"""
+        try:
+            self._push_event(evt)
+        except Exception as e:
+            print(f"Unexpected error in callback for {evt}: {e}", file=self._fd)
+
+
 def get_home():
     """
     Find user's home directory if possible. Otherwise raise error.
@@ -2089,3 +2043,683 @@ class InvalidTangoHostTrlError(ValueError):
 class PyTangoUserWarning(UserWarning):
     # a custom category for all PyTango's warnings to give users the option of filtering PyTango's warnings
     pass
+
+
+def _is_coroutine_function(obj):
+    while isinstance(obj, functools.partial):
+        obj = obj.func
+
+    return inspect.iscoroutinefunction(obj) or (
+        callable(obj) and inspect.iscoroutinefunction(obj.__call__)
+    )
+
+
+def _truthy_env_var(name) -> bool:
+    value = ApiUtil.get_env_var(name)
+    if value and value.lower() in {"on", "1", "true", "yes", "y"}:
+        return True
+    return False
+
+
+_debug_run_active = False
+try:
+    import pydevd
+
+    _debugger = pydevd.get_global_debugger()
+    _disabled_via_env_var = _truthy_env_var("PYTANGO_DISABLE_DEBUG_TRACE_PATCHING")
+    if _debugger is not None and not _disabled_via_env_var:
+        _debug_run_active = True
+        warnings.warn(
+            "pydevd debugger detected: tango.server.Device methods "
+            "will be patched for tracing.",
+            category=PyTangoUserWarning,
+        )
+except Exception:
+    pass
+
+
+_coverage_run_active = False
+
+try:
+    import coverage
+
+    if coverage.Coverage.current():
+        if _truthy_env_var("PYTANGO_DISABLE_COVERAGE_TRACE_PATCHING"):
+            warnings.warn(
+                "Coverage run detected, but PYTANGO_DISABLE_COVERAGE_TRACE_PATCHING "
+                "environment variable is set. Reported coverage may be inaccurate.",
+                category=PyTangoUserWarning,
+            )
+        elif _debug_run_active:
+            warnings.warn(
+                "Coverage run detected, but debugger also detected. "
+                "Patching only for debugger, not for coverage."
+                "Reported coverage may be inaccurate.",
+                category=PyTangoUserWarning,
+            )
+        else:
+            if getattr(threading, "_trace_hook", None):
+                _coverage_run_active = True
+                warnings.warn(
+                    "Coverage run detected: tango.server.Device methods "
+                    "will be patched for tracing.",
+                    category=PyTangoUserWarning,
+                )
+            else:
+                warnings.warn(
+                    "Coverage run detected, but unable to get threading._trace_hook. "
+                    "Reported coverage may be inaccurate.",
+                    category=PyTangoUserWarning,
+                )
+
+except Exception:
+    pass
+
+
+_telemetry_active = False
+try:
+    _globally_enabled_via_env_var = _truthy_env_var("TANGO_TELEMETRY_ENABLE")
+    _locally_disabled_via_env_var = _truthy_env_var(
+        "PYTANGO_DISABLE_TELEMETRY_PATCHING"
+    )
+    if (
+        _globally_enabled_via_env_var
+        and not _locally_disabled_via_env_var
+        and TELEMETRY_SUPPORTED
+    ):
+        from opentelemetry import trace as trace_api
+        from opentelemetry.trace.propagation.tracecontext import (
+            TraceContextTextMapPropagator,
+        )
+
+        _traces_exporter_type = ApiUtil.get_env_var("TANGO_TELEMETRY_TRACES_EXPORTER")
+        if not _traces_exporter_type:
+            _traces_exporter_type = "console"
+        _traces_exporter_endpoint = ApiUtil.get_env_var(
+            "TANGO_TELEMETRY_TRACES_ENDPOINT"
+        )
+
+        _telemetry_sdk_available = False
+        try:
+            _traces_exporter_kwargs = {}
+            if _traces_exporter_type.lower() == "grpc":
+                from opentelemetry.exporter.otlp.proto.grpc.trace_exporter import (
+                    OTLPSpanExporter as SpanExporter,
+                )
+
+                if _traces_exporter_endpoint:
+                    _traces_exporter_endpoint = _traces_exporter_endpoint.lower()
+                    if _traces_exporter_endpoint.startswith("grpc://"):
+                        # cppTango requires endpoints starting "grpc://" for gRPC, even
+                        # though this is a non-standard scheme.  We convert to
+                        # the more standard http:// for the OTel exporter library.
+                        _traces_exporter_endpoint = _traces_exporter_endpoint.replace(
+                            "grpc://", "http://"
+                        )
+                    _traces_exporter_kwargs = {"endpoint": _traces_exporter_endpoint}
+            elif _traces_exporter_type.lower() == "http":
+                from opentelemetry.exporter.otlp.proto.http.trace_exporter import (
+                    OTLPSpanExporter as SpanExporter,
+                )
+
+                if _traces_exporter_endpoint:
+                    _traces_exporter_kwargs = {"endpoint": _traces_exporter_endpoint}
+            elif _traces_exporter_type.lower() == "none":
+                SpanExporter = None
+            else:
+                from opentelemetry.sdk.trace.export import (
+                    ConsoleSpanExporter as SpanExporter,
+                )
+
+                if _traces_exporter_endpoint:
+                    if _traces_exporter_endpoint.lower() == "cerr":
+                        _traces_exporter_kwargs = {"out": sys.stderr}
+                    else:
+                        _traces_exporter_kwargs = {"out": sys.stdout}
+
+                if _traces_exporter_type.lower() != "console":
+                    warnings.warn(
+                        f"Unknown value '{_traces_exporter_type}' for "
+                        f"TANGO_TELEMETRY_TRACES_EXPORTER. Options are: "
+                        f"'console', 'grpc', 'http' and 'none'. Defaulting to 'console'."
+                    )
+                    _traces_exporter_type = "console"
+
+            from opentelemetry.sdk.resources import (
+                HOST_NAME,
+                SERVICE_INSTANCE_ID,
+                SERVICE_NAME,
+                SERVICE_NAMESPACE,
+                Resource,
+            )
+            from opentelemetry.sdk.trace import TracerProvider
+            from opentelemetry.sdk.trace.export import (
+                BatchSpanProcessor,
+                SimpleSpanProcessor,
+            )
+
+            _telemetry_sdk_available = True
+        except ImportError:
+            warnings.warn(
+                "OpenTelemetry SDK packages not available: "
+                "no telemetry traces will be emitted from this device/client.\n"
+                "To emit telemetry, install the SDK packages: "
+                "opentelemetry-sdk and either:\n"
+                "  opentelemetry-exporter-otlp-proto-grpc (for traces via gRPC), or\n"
+                "  opentelemetry-exporter-otlp-proto-http (for traces via HTTP).\n"
+                "This warning can be disabled.\n"
+                "  Either set environment variable PYTANGO_DISABLE_TELEMETRY_PATCHING=on"
+                " to disable PyTango's usage of telemetry.\n"
+                "  Or, set the environment variable TANGO_TELEMETRY_ENABLE=off to "
+                "disable all telemetry in cppTango and PyTango.",
+                category=PyTangoUserWarning,
+            )
+
+        @contextlib.contextmanager
+        def _span_from_cpptango(
+            device: "tango.server.Device", fn: callable  # noqa: F821
+        ) -> typing.Iterator[trace_api.Span]:
+            fn = inspect.unwrap(fn)
+            name = getattr(fn, "__qualname__", getattr(fn, "__name__", "unknown"))
+            carrier = _telemetry.get_trace_context()
+            ctx = TraceContextTextMapPropagator().extract(carrier=carrier)
+            device_tracer = device.get_telemetry_tracer()
+            token = _current_telemetry_tracer.set(device_tracer)
+            try:
+                with device_tracer.start_as_current_span(
+                    name, context=ctx, kind=trace_api.SpanKind.SERVER
+                ) as span:
+                    span.set_attribute("code.filepath", fn.__code__.co_filename)
+                    span.set_attribute("code.lineno", fn.__code__.co_firstlineno)
+                    current_thread = threading.current_thread()
+                    span.set_attribute("thread.id", hex(current_thread.ident))
+                    span.set_attribute("thread.name", current_thread.name)
+                    yield span
+            finally:
+                _current_telemetry_tracer.reset(token)
+
+        @contextlib.contextmanager
+        def _span_to_cpptango(name: str):
+            # use propagator to get W3C strings from active Python OpenTelemetry context
+            carrier = {}
+            TraceContextTextMapPropagator().inject(carrier)
+            traceparent = carrier.get("traceparent", "")
+            tracestate = carrier.get("tracestate", "")
+            # create C++ TraceContextScope and set context from Python context
+            with _telemetry.TraceContextScope(name, traceparent, tracestate):
+                yield
+
+        def _default_telemetry_tracer_provider_factory(
+            service_name: str,
+            service_instance_id: typing.Union[None, str] = None,
+            extra_resource_attributes: typing.Union[None, dict[str, str]] = None,
+        ) -> trace_api.TracerProvider:
+            """Create default telemetry TracerProvider for a device.
+
+            A TraceProvider is not used directly, but rather used to create a Tracer.
+
+            See also OpenTelemetry's OTEL_EXPERIMENTAL_RESOURCE_DETECTORS environment
+            variable, and other resource detectors. It may be possible to add additional
+            information just using this environment variable.
+            """
+            if _telemetry_sdk_available and SpanExporter is not None:
+                resource_attributes = {
+                    HOST_NAME: socket.getfqdn(),
+                    SERVICE_NAMESPACE: "tango",
+                    SERVICE_NAME: service_name,
+                }
+                if service_instance_id:
+                    resource_attributes[SERVICE_INSTANCE_ID] = service_instance_id
+                if extra_resource_attributes:
+                    resource_attributes.update(extra_resource_attributes)
+                tracer_provider = TracerProvider(
+                    resource=Resource.create(resource_attributes)
+                )
+                exporter = SpanExporter(**_traces_exporter_kwargs)
+                processor = _create_span_processor(exporter)
+                tracer_provider.add_span_processor(processor)
+            else:
+                tracer_provider = trace_api.NoOpTracerProvider()
+            return tracer_provider
+
+        def _create_span_processor(exporter):
+            processor_type = ApiUtil.get_env_var(
+                "PYTANGO_TELEMETRY_SPAN_PROCESSOR_TYPE"
+            )
+            if processor_type and processor_type.lower() == "simple":
+                processor_class = SimpleSpanProcessor
+            elif processor_type and processor_type.lower() == "batch":
+                processor_class = BatchSpanProcessor
+            else:
+                if _traces_exporter_type.lower() == "console":
+                    processor_class = SimpleSpanProcessor
+                else:
+                    processor_class = BatchSpanProcessor
+            processor = processor_class(exporter)
+            return processor
+
+        def _create_device_telemetry_tracer(
+            tracer_provider: trace_api.TracerProvider,
+        ) -> trace_api.Tracer:
+            """Create a standard telemetry Tracer for a device."""
+            # See the following link for details on tracer naming:
+            #   https://github.com/open-telemetry/opentelemetry-specification/blob/main/specification/trace/api.md#get-a-tracer
+            # cppTango uses "tango.cpp".  We use "tango.python.server"
+            device_tracer = trace_api.get_tracer(
+                instrumenting_module_name="tango.python.server",
+                instrumenting_library_version=Release.version,
+                tracer_provider=tracer_provider,
+            )
+            return device_tracer
+
+        def _create_client_telemetry_tracer() -> trace_api.Tracer:
+            service_name = ApiUtil.get_env_var("PYTANGO_TELEMETRY_CLIENT_SERVICE_NAME")
+            if not service_name:
+                service_name = "pytango.client"
+            tracer_provider_factory = get_telemetry_tracer_provider_factory()
+            tracer_provider = tracer_provider_factory(service_name)
+            # See comment in _create_device_telemetry_tracer about naming.
+            # We differentiate between client and server tracers.
+            tracer = trace_api.get_tracer(
+                instrumenting_module_name="tango.python.client",
+                instrumenting_library_version=Release.version,
+                tracer_provider=tracer_provider,
+            )
+            return tracer
+
+        _telemetry_client_tracer: typing.Union[None, trace_api.Tracer] = None
+        _telemetry_active = True
+except ImportError:
+    warnings.warn(
+        "\nOpenTelemetry packages not available: \n"
+        "telemetry context will not be passed to other Tango devices, "
+        "and no telemetry will be emitted from this device/client.\n"
+        "To pass through telemetry context, install the API packages: "
+        "opentelemetry-api\n"
+        "To emit telemetry, install the SDK packages: "
+        "opentelemetry-sdk and either:\n"
+        "  opentelemetry-exporter-otlp-proto-grpc (for traces via gRPC), or\n"
+        "  opentelemetry-exporter-otlp-proto-http (for traces via HTTP).\n"
+        "This warning can be disabled:\n"
+        "  Either set environment variable PYTANGO_DISABLE_TELEMETRY_PATCHING=on "
+        "to disable PyTango's usage of telemetry.\n"
+        "  Or, set the environment variable TANGO_TELEMETRY_ENABLE=off to disable "
+        "all telemetry in cppTango and PyTango.",
+        category=PyTangoUserWarning,
+    )
+except Exception as exc:
+    warnings.warn(
+        f"Error setting up telemetry. Telemetry context may not be passed on "
+        f"and traces may not be emitted. Possibly a PyTango bug.\n"
+        f"Error: {exc!r}"
+    )
+
+
+_DummySpanContext = namedtuple(
+    "_DummySpanContext",
+    ["trace_id", "span_id", "is_remote", "trace_flags", "trace_state", "is_valid"],
+)
+
+
+class _DummySpan:
+    def set_attributes(self, *args, **kwargs):
+        pass
+
+    def set_attribute(self, *args, **kwargs):
+        pass
+
+    def add_event(self, *args, **kwargs):
+        pass
+
+    def add_link(self, *args, **kwargs):
+        pass
+
+    def update_name(self, *args, **kwargs):
+        pass
+
+    def is_recording(self):
+        return False
+
+    def set_status(self, *args, **kwargs):
+        pass
+
+    def record_exception(self, *args, **kwargs):
+        pass
+
+    def end(self, *args, **kwargs):
+        pass
+
+    def get_span_context(self):
+        return _DummySpanContext(0, 0, False, 0, {}, False)
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, *args, **kwargs):
+        self.end()
+
+
+class _DummyTracer:
+    def start_span(self, *args, **kwargs):
+        pass
+
+    @contextlib.contextmanager
+    def start_as_current_span(self, *args, **kwargs):
+        yield _DummySpan()
+
+
+class _DummyTracerProvider:
+    def get_tracer(self, *args, **kwargs):
+        return _DummyTracer()
+
+
+if not _telemetry_active:
+    # define dummy handlers
+
+    @contextlib.contextmanager
+    def _span_to_cpptango():
+        yield
+
+    def _default_telemetry_tracer_provider_factory(
+        service_name, service_instance_id=None, extra_resource_attributes=None
+    ):
+        return _DummyTracerProvider()
+
+    def _create_device_telemetry_tracer(tracer_provider) -> _DummyTracer:
+        return _DummyTracer()
+
+    _telemetry_client_tracer = None
+
+_current_telemetry_tracer = ContextVar("current_telemetry_tracer")
+
+_current_telemetry_tracer_provider_factory = _default_telemetry_tracer_provider_factory
+
+
+class _TracerProviderFactory(typing.Protocol):
+    def __call__(
+        self,
+        service_name: str,
+        service_instance_id: typing.Union[None, str] = None,
+        extra_resource_attributes: typing.Union[None, dict[str, str]] = None,
+    ) -> "opentelemetry.trace.TracerProvider":  # noqa: F821
+        ...
+
+
+def set_telemetry_tracer_provider_factory(provider_factory: _TracerProviderFactory):
+    """Change the factory that will be used to create tracer providers.
+
+    The factory is called when a tracer provider needs to be created.
+    I.e., once for client access, and once for each device.
+    """
+    global _current_telemetry_tracer_provider_factory
+    _current_telemetry_tracer_provider_factory = provider_factory
+
+
+def get_telemetry_tracer_provider_factory() -> _TracerProviderFactory:
+    """Get the factory that will be used to create tracer providers."""
+    return _current_telemetry_tracer_provider_factory
+
+
+_force_tracing = _debug_run_active or _coverage_run_active or _telemetry_active
+
+
+def _forcefully_traced_method(fn, is_kernel_method=False):
+    # late import to avoid circular reference
+    from tango.server import BaseDevice
+
+    unwrapped_fn = inspect.unwrap(fn)
+
+    def _get_device_telemetry_required(*args):
+        device = None
+        telemetry_required = False
+        if _telemetry_active and args:
+            first = args[0]
+            if isinstance(first, BaseDevice):
+                device = first
+            else:
+                fn_self = getattr(unwrapped_fn, "__self__", None)
+                if isinstance(fn_self, BaseDevice):
+                    device = fn_self
+            if device is not None:
+                telemetry_required = device.is_telemetry_enabled() and (
+                    not is_kernel_method or device.is_kernel_tracing_enabled()
+                )
+        return device, telemetry_required
+
+    def _set_sys_tracer_and_get_original():
+        original_sys_tracer = "EMPTY"
+
+        if _debug_run_active:
+            pydevd.settrace(suspend=False, trace_only_current_thread=True)
+        elif _coverage_run_active:
+            original_sys_tracer = sys.gettrace()
+            threading_trace_hook = getattr(threading, "_trace_hook", None)
+            if threading_trace_hook:
+                sys.settrace(threading_trace_hook)
+        return original_sys_tracer
+
+    @functools.wraps(fn)
+    def trace_wrapper(*args, **kwargs):
+        device, telemetry_required = _get_device_telemetry_required(*args)
+        original_sys_tracer = _set_sys_tracer_and_get_original()
+        try:
+            if telemetry_required and device is not None:
+                with _span_from_cpptango(device, fn):
+                    ret = fn(*args, **kwargs)
+            else:
+                ret = fn(*args, **kwargs)
+        finally:
+            if original_sys_tracer != "EMPTY":
+                sys.settrace(original_sys_tracer)
+        return ret
+
+    @functools.wraps(fn)
+    async def async_trace_wrapper(*args, **kwargs):
+        device, telemetry_required = _get_device_telemetry_required(*args)
+        original_sys_tracer = _set_sys_tracer_and_get_original()
+        try:
+            if telemetry_required and device is not None:
+                with _span_from_cpptango(device, fn):
+                    ret = await fn(*args, **kwargs)
+            else:
+                ret = await fn(*args, **kwargs)
+        finally:
+            if original_sys_tracer != "EMPTY":
+                sys.settrace(original_sys_tracer)
+        return ret
+
+    if _is_coroutine_function(fn):
+        return async_trace_wrapper
+    else:
+        return trace_wrapper
+
+
+def _trace_client(fn):
+    """Wrapper/decorator to trace a client function for telemetry."""
+
+    if _telemetry_active:
+        # Change function names like "__DeviceProxy__subscribe_event" to
+        # "DeviceProxy.subscribe_event" for better readability
+        fn_name = getattr(fn, "__qualname__", getattr(fn, "__name__", "unknown"))
+        match = re.match(r"__(?P<prefix>\w+?)__(?P<suffix>.*)", fn_name)
+        if match:
+            fn_name = f"{match.group('prefix')}.{match.group('suffix')}"
+
+        @functools.wraps(fn)
+        def client_trace_wrapper(*args, **kwargs):
+            global _telemetry_client_tracer
+            if _telemetry_client_tracer is None:
+                _telemetry_client_tracer = _create_client_telemetry_tracer()
+            tracer = _current_telemetry_tracer.get(_telemetry_client_tracer)
+            filename, lineno, qualname = _get_non_tango_source_location()
+            with tracer.start_as_current_span(
+                qualname, kind=trace_api.SpanKind.CLIENT
+            ) as span:
+                span.set_attribute("code.filepath", filename)
+                span.set_attribute("code.lineno", lineno)
+                current_thread = threading.current_thread()
+                span.set_attribute("thread.id", hex(current_thread.ident))
+                span.set_attribute("thread.name", current_thread.name)
+                with _span_to_cpptango(fn_name):
+                    return fn(*args, **kwargs)
+
+    else:
+        client_trace_wrapper = fn
+
+    return client_trace_wrapper
+
+
+_SourceLocation = namedtuple("_SourceLocation", ("filepath", "lineno", "qualname"))
+
+
+def _get_non_tango_source_location(
+    source: typing.Union[callable, None] = None
+) -> _SourceLocation:
+    """Provides non-PyTango source caller for logging and tracing functions.
+
+    :param source:
+        (optional) Method or function, which will be unwrapped of decorated wrappers
+        and inspected for location. If not provided - current stack will be used to
+        deduce the location.
+    :type source: Callable
+
+    :return:
+        Named tuple (filepath, lineno, qualname)
+    :rtype :_SourceLocation:
+    """
+    try:
+        if source:
+            # If source is a wrapped function - unwrap it to inner function
+            source = inspect.unwrap(source)
+            # Find callable code location
+            code = getattr(source, "__code__", None)
+            if code:
+                filepath = code.co_filename
+                lineno = code.co_firstlineno
+                qualname = getattr(
+                    code, "co_qualname", getattr(code, "co_name", str(source))
+                )
+                return _SourceLocation(filepath, lineno, qualname)
+        else:
+            caller, module = _get_first_non_tango_caller_and_module()
+            if caller:
+                code = caller.f_code
+                filepath = code.co_filename
+                lineno = caller.f_lineno
+                qualname = getattr(
+                    code,
+                    "co_qualname",
+                    getattr(code, "co_name", "unknown"),
+                )
+                if qualname == "<module>" and module in ("__main__", "__mp_main__"):
+                    qualname = module
+                return _SourceLocation(filepath, lineno, qualname)
+        return _SourceLocation("(unknown)", 0, str(source))
+    except Exception:
+        return _SourceLocation("(unknown)", 0, str(source))
+
+
+# Search the call stack until we are out of the 'tango' module. We cannot
+# have a fixed number here because loggers/streams/tracing is used in many places
+# inside pytango with varying call stack depth.
+#
+# There are different option below which trade compatibility for speed (fastest first).
+if hasattr(sys, "_getframemodulename") and hasattr(sys, "_getframe"):
+
+    def _get_first_non_tango_caller_and_module():
+        depth = 2
+        caller = None
+        while True:
+            module = sys._getframemodulename(depth)  # added in Python 3.12
+            if module != "tango" and not module.startswith("tango."):
+                caller = sys._getframe(depth)
+                break
+            elif module is None:
+                break  # stack exhausted
+            depth += 1
+        if caller:
+            return caller, module
+        else:
+            return None, ""
+
+elif hasattr(sys, "_getframe"):
+
+    def _get_first_non_tango_caller_and_module():
+        depth = 2
+        caller = None
+        module = ""
+        try:
+            while True:
+                caller = sys._getframe(depth)
+                module = caller.f_globals["__name__"]
+                if module != "tango" and not module.startswith("tango."):
+                    break
+                depth += 1
+        except ValueError:
+            pass  # stack exhausted
+        if caller:
+            return caller, module
+        else:
+            return None, ""
+
+else:
+    # use inspect (the slowest approach, most portable)
+    def _get_first_non_tango_caller_and_module():
+        for caller, _, _, _, _, _ in inspect.stack(0):
+            module = caller.f_globals["__name__"]
+            if module != "tango" and not module.startswith("tango."):
+                return caller, module
+        return None, ""
+
+
+# Since cppTango based on omniThreads, we have to slightly modify ThreadPoolExecutor,
+# to use threads with ensured dummy omniORB ID
+#
+# The `_adjust_thread_count` method below is a slightly modified version of the code from
+# https://github.com/python/cpython/blob/3.12/Lib/concurrent/futures/thread.py
+
+# Copyright (c) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010,
+# 2011, 2012, 2013, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022,
+# 2023 Python Software Foundation;
+# All Rights Reserved
+
+from concurrent.futures import ThreadPoolExecutor
+from concurrent.futures.thread import _worker, _threads_queues
+
+
+class PyTangoThreadPoolExecutor(ThreadPoolExecutor):
+    """
+    Based on concurrent.futures.ThreadPoolExecutor, but additionally ensures dummy omniORB runs for every running thread.
+    """
+
+    def _adjust_thread_count(self):
+        # if idle threads are available, don't spin new threads
+        if self._idle_semaphore.acquire(timeout=0):
+            return
+
+        # When the executor gets lost, the weakref callback will wake up
+        # the worker threads.
+        def weakref_cb(_, q=self._work_queue):
+            q.put(None)
+
+        num_threads = len(self._threads)
+        if num_threads < self._max_workers:
+            thread_name = "%s_%d" % (self._thread_name_prefix or self, num_threads)
+            t = threading.Thread(
+                name=thread_name,
+                target=_thread_pool_executor_worker,
+                args=(
+                    weakref.ref(self, weakref_cb),
+                    self._work_queue,
+                    self._initializer,
+                    self._initargs,
+                ),
+            )
+            t.start()
+            self._threads.add(t)
+            _threads_queues[t] = self._work_queue
+
+
+def _thread_pool_executor_worker(executor_reference, work_queue, initializer, initargs):
+    with EnsureOmniThread():
+        _worker(executor_reference, work_queue, initializer, initargs)
