@@ -28,12 +28,13 @@ WINDOWS = "nt" in os.name
 
 
 class Device1(Device):
+    _attr1 = 100
+
     def init_device(self):
         super().init_device()
         self.set_state(tango.DevState.ON)
-        self._attr1 = 100
 
-    @attribute(access=AttrWriteType.READ_WRITE)
+    @attribute(dtype=int, access=AttrWriteType.READ_WRITE)
     def attr1(self):
         return self._attr1
 
@@ -41,28 +42,6 @@ class Device1(Device):
         self._attr1 = value
 
 
-class Device2(Device):
-    def init_device(self):
-        super().init_device()
-        self.set_state(tango.DevState.ON)
-        self._attr2 = 200
-
-    @attribute
-    def attr2(self):
-        return self._attr2
-
-
-class Device3(Device):
-    def init_device(self):
-        super().init_device()
-        self.my_proxy = tango.DeviceProxy("test/device1/1")
-        self.set_state(tango.DevState.ON)
-
-    @attribute
-    def attr3(self):
-        return self.my_proxy.attr1
-
-
 class Device1GreenModeUnspecified(Device1):
     pass
 
@@ -75,9 +54,34 @@ class Device1Gevent(Device1):
     green_mode = GreenMode.Gevent
 
 
-class Device1Asyncio(Device1):
+class Device1Asyncio(Device):
     green_mode = GreenMode.Asyncio
 
+    _attr1 = 100
+
+    async def init_device(self):
+        await super().init_device()
+        self.set_state(tango.DevState.ON)
+
+    @attribute(dtype=int, access=AttrWriteType.READ_WRITE)
+    async def attr1(self):
+        return self._attr1
+
+    async def write_attr1(self, value):
+        self._attr1 = value
+
+
+class Device2(Device):
+    _attr2 = 200
+
+    def init_device(self):
+        super().init_device()
+        self.set_state(tango.DevState.ON)
+
+    @attribute
+    def attr2(self):
+        return self._attr2
+
 
 class Device2GreenModeUnspecified(Device2):
     pass
@@ -91,16 +95,29 @@ class Device2Gevent(Device2):
     green_mode = GreenMode.Gevent
 
 
-class Device2Asyncio(Device2):
+class Device2Asyncio(Device):
     green_mode = GreenMode.Asyncio
 
-
-class Device1AsyncInit(Device1):
-    green_mode = GreenMode.Asyncio
+    _attr2 = 200
 
     async def init_device(self):
         await super().init_device()
-        self._attr1 = 150
+        self.set_state(tango.DevState.ON)
+
+    @attribute
+    async def attr2(self):
+        return self._attr2
+
+
+class Device3(Device):
+    def init_device(self):
+        super().init_device()
+        self.my_proxy = tango.DeviceProxy("test/device1/1")
+        self.set_state(tango.DevState.ON)
+
+    @attribute
+    def attr3(self):
+        return self.my_proxy.attr1
 
 
 def test_no_warnings_in_test_context():
@@ -113,18 +130,20 @@ def test_no_warnings_in_test_context():
 
 
 def test_single_device(server_green_mode):
-    class TestDevice(Device1):
-        green_mode = server_green_mode
+    if server_green_mode == GreenMode.Asyncio:
+
+        class TestDevice(Device1Asyncio):
+            pass
+
+    else:
+
+        class TestDevice(Device1):
+            green_mode = server_green_mode
 
     with DeviceTestContext(TestDevice) as proxy:
         assert proxy.attr1 == 100
 
 
-def test_single_async_init_device():
-    with DeviceTestContext(Device1AsyncInit) as proxy:
-        assert proxy.attr1 == 150
-
-
 def test_single_device_old_api():
     with DeviceTestContext(
         ClassicAPISimpleDeviceImpl, ClassicAPISimpleDeviceClass
@@ -199,8 +218,15 @@ def test_multi_devices_info(class_field, device):
 
 
 def test_multi_with_single_device(server_green_mode):
-    class TestDevice(Device1):
-        green_mode = server_green_mode
+    if server_green_mode == GreenMode.Asyncio:
+
+        class TestDevice(Device1Asyncio):
+            pass
+
+    else:
+
+        class TestDevice(Device1):
+            green_mode = server_green_mode
 
     devices_info = ({"class": TestDevice, "devices": [{"name": "test/device1/1"}]},)
 
@@ -223,11 +249,21 @@ def test_multi_with_single_device_old_api():
 
 
 def test_multi_with_two_devices(server_green_mode):
-    class TestDevice1(Device1):
-        green_mode = server_green_mode
+    if server_green_mode == GreenMode.Asyncio:
 
-    class TestDevice2(Device2):
-        green_mode = server_green_mode
+        class TestDevice1(Device1Asyncio):
+            pass
+
+        class TestDevice2(Device2Asyncio):
+            pass
+
+    else:
+
+        class TestDevice1(Device1):
+            green_mode = server_green_mode
+
+        class TestDevice2(Device2):
+            green_mode = server_green_mode
 
     devices_info = (
         {"class": TestDevice1, "devices": [{"name": "test/device1/1"}]},
@@ -330,20 +366,6 @@ def test_multi_with_mixed_device_green_modes(first_type, second_type, exception_
             None,
             SynchronousExecutor,
         ),
-        (
-            Device1GreenModeUnspecified,
-            GreenMode.Asyncio,
-            GreenMode.Synchronous,
-            None,
-            AsyncioExecutor,
-        ),
-        (
-            Device1GreenModeUnspecified,
-            GreenMode.Asyncio,
-            GreenMode.Gevent,
-            None,
-            AsyncioExecutor,
-        ),
         (
             Device1GreenModeUnspecified,
             GreenMode.Gevent,
@@ -367,6 +389,23 @@ def test_multi_with_mixed_device_green_modes(first_type, second_type, exception_
             None,
             SynchronousExecutor,
         ),
+        # Deprecated modes - starting from PyTango 10 it is deprecated
+        # to modify sync servers to async "on the fly".
+        # All base methods should be defined with "async def" instead.
+        (
+            Device1GreenModeUnspecified,
+            GreenMode.Asyncio,
+            GreenMode.Synchronous,
+            DeprecationWarning,
+            AsyncioExecutor,
+        ),
+        (
+            Device1GreenModeUnspecified,
+            GreenMode.Asyncio,
+            GreenMode.Gevent,
+            DeprecationWarning,
+            AsyncioExecutor,
+        ),
         # Unsupported modes - device servers with the following combinations
         # fail to start up. The cause is unknown. This could be fixed in the future.
         (
@@ -392,7 +431,6 @@ def test_green_modes_in_device_kwarg_and_global(
 ):
     if WINDOWS and exception_type is not None:
         pytest.skip("Skip test that hangs on Windows")
-        return
 
     old_green_mode = tango.get_green_mode()
     try:
@@ -401,23 +439,24 @@ def test_green_modes_in_device_kwarg_and_global(
         if exception_type is None:
             with DeviceTestContext(device_type, green_mode=green_mode):
                 pass
-            assert type(get_worker()) == executor_type
+        elif exception_type is DeprecationWarning:
+            with pytest.warns((DeprecationWarning, RuntimeWarning)):
+                with DeviceTestContext(device_type, green_mode=green_mode):
+                    pass
         else:
             with pytest.raises(exception_type, match=r"stuck at init"):
                 with DeviceTestContext(device_type, green_mode=green_mode, timeout=0.5):
                     pass
+        assert type(get_worker()) == executor_type
 
     finally:
         tango.set_green_mode(old_green_mode)
 
 
 def test_multi_with_async_devices_initialised():
-    class TestDevice2Async(Device2):
-        green_mode = GreenMode.Asyncio
-
     devices_info = (
-        {"class": Device1AsyncInit, "devices": [{"name": "test/device1/1"}]},
-        {"class": TestDevice2Async, "devices": [{"name": "test/device2/1"}]},
+        {"class": Device1Asyncio, "devices": [{"name": "test/device1/1"}]},
+        {"class": Device2Asyncio, "devices": [{"name": "test/device2/1"}]},
     )
 
     with MultiDeviceTestContext(devices_info) as context:
@@ -425,7 +464,7 @@ def test_multi_with_async_devices_initialised():
         proxy2 = context.get_device("test/device2/1")
         assert proxy1.State() == tango.DevState.ON
         assert proxy2.State() == tango.DevState.ON
-        assert proxy1.attr1 == 150
+        assert proxy1.attr1 == 100
         assert proxy2.attr2 == 200
 
 
@@ -570,23 +609,45 @@ def test_multi_device_proxy_cached():
 
 
 def test_multi_with_two_devices_with_properties(server_green_mode):
-    class TestDevice1(Device):
-        green_mode = server_green_mode
+    if server_green_mode == GreenMode.Asyncio:
 
-        prop1 = device_property(dtype=str)
+        class TestDevice1(Device):
+            green_mode = server_green_mode
 
-        @command(dtype_out=str)
-        def get_prop1(self):
-            return self.prop1
+            prop1 = device_property(dtype=str)
 
-    class TestDevice2(Device):
-        green_mode = server_green_mode
+            @command(dtype_out=str)
+            async def get_prop1(self):
+                return self.prop1
 
-        prop2 = device_property(dtype=int)
+        class TestDevice2(Device):
+            green_mode = server_green_mode
 
-        @command(dtype_out=int)
-        def get_prop2(self):
-            return self.prop2
+            prop2 = device_property(dtype=int)
+
+            @command(dtype_out=int)
+            async def get_prop2(self):
+                return self.prop2
+
+    else:
+
+        class TestDevice1(Device):
+            green_mode = server_green_mode
+
+            prop1 = device_property(dtype=str)
+
+            @command(dtype_out=str)
+            def get_prop1(self):
+                return self.prop1
+
+        class TestDevice2(Device):
+            green_mode = server_green_mode
+
+            prop2 = device_property(dtype=int)
+
+            @command(dtype_out=int)
+            def get_prop2(self):
+                return self.prop2
 
     devices_info = (
         {
